@@ -13,15 +13,14 @@
 ###############################################################################
 import copy
 import warnings
+
 import numpy
-from .actionAngle import actionAngle
+
 from ..potential import IsochronePotential
-from ..util import galpyWarning
-_APY_LOADED= True
-try:
-    from astropy import units
-except ImportError:
-    _APY_LOADED= False
+from ..util import conversion, galpyWarning
+from .actionAngle import actionAngle
+
+
 class actionAngleIsochrone(actionAngle):
     """Action-angle formalism for the isochrone potential, on the Jphi, Jtheta system of Binney & Tremaine (2008)"""
     def __init__(self,*args,**kwargs):
@@ -42,7 +41,7 @@ class actionAngleIsochrone(actionAngle):
            vo= circular velocity at ro (km/s; can be Quantity)
 
         OUTPUT:
-        
+
            instance
 
         HISTORY:
@@ -51,20 +50,18 @@ class actionAngleIsochrone(actionAngle):
         actionAngle.__init__(self,
                              ro=kwargs.get('ro',None),vo=kwargs.get('vo',None))
         if not 'b' in kwargs and not 'ip' in kwargs: #pragma: no cover
-            raise IOError("Must specify b= for actionAngleIsochrone")
+            raise OSError("Must specify b= for actionAngleIsochrone")
         if 'ip' in kwargs:
             ip= kwargs['ip']
             if not isinstance(ip,IsochronePotential): #pragma: no cover
-                raise IOError("'Provided ip= does not appear to be an instance of an IsochronePotential")
+                raise OSError("'Provided ip= does not appear to be an instance of an IsochronePotential")
             # Check the units
             self._pot= ip
             self._check_consistent_units()
             self.b= ip.b
             self.amp= ip._amp
         else:
-            self.b= kwargs['b']
-            if _APY_LOADED and isinstance(self.b,units.Quantity):
-                self.b= self.b.to(units.kpc).value/self._ro
+            self.b= conversion.parse_length(kwargs['b'],ro=self._ro)
             rb= numpy.sqrt(self.b**2.+1.)
             self.amp= (self.b+rb)**2.*rb
         self._c= False
@@ -81,7 +78,7 @@ class actionAngleIsochrone(actionAngle):
         # Check the units
         self._check_consistent_units()
         return None
-    
+
     def _evaluate(self,*args,**kwargs):
         """
         NAME:
@@ -129,7 +126,7 @@ class actionAngleIsochrone(actionAngle):
             Jphi= Lz
             Jz= L-numpy.fabs(Lz)
             Jr= self.amp/numpy.sqrt(-2.*E)\
-                -0.5*(L+numpy.sqrt((L2+4.*self.amp*self.b)))
+                -0.5*(L+numpy.sqrt(L2+4.*self.amp*self.b))
             return (Jr,Jphi,Jz)
 
     def _actionsFreqs(self,*args,**kwargs):
@@ -179,7 +176,7 @@ class actionAngleIsochrone(actionAngle):
             Jphi= Lz
             Jz= L-numpy.fabs(Lz)
             Jr= self.amp/numpy.sqrt(-2.*E)\
-                -0.5*(L+numpy.sqrt((L2+4.*self.amp*self.b)))
+                -0.5*(L+numpy.sqrt(L2+4.*self.amp*self.b))
             #Frequencies
             Omegar= (-2.*E)**1.5/self.amp
             Omegaz= 0.5*(1.+L/numpy.sqrt(L2+4.*self.amp*self.b))*Omegar
@@ -206,7 +203,7 @@ class actionAngleIsochrone(actionAngle):
            2013-09-08 - Written - Bovy (IAS)
         """
         if len(args) == 5: #R,vR.vT, z, vz pragma: no cover
-            raise IOError("You need to provide phi when calculating angles")
+            raise OSError("You need to provide phi when calculating angles")
         elif len(args) == 6: #R,vR.vT, z, vz, phi
             R,vR,vT, z, vz, phi= args
         else:
@@ -237,7 +234,7 @@ class actionAngleIsochrone(actionAngle):
             Jphi= Lz
             Jz= L-numpy.fabs(Lz)
             Jr= self.amp/numpy.sqrt(-2.*E)\
-                -0.5*(L+numpy.sqrt((L2+4.*self.amp*self.b)))
+                -0.5*(L+numpy.sqrt(L2+4.*self.amp*self.b))
             #Frequencies
             Omegar= (-2.*E)**1.5/self.amp
             Omegaz= 0.5*(1.+L/numpy.sqrt(L2+4.*self.amp*self.b))*Omegar
@@ -253,10 +250,10 @@ class actionAngleIsochrone(actionAngle):
             else:
                 s= 1.+numpy.sqrt(1.+(R**2.+z**2.)/self.b**2.)
                 coseta= 1/e*(1.-self.b/c*(s-2.))
-            pindx= (coseta > 1.)*(coseta < (1.+10.**-7.))
+            pindx= (coseta > 1.)
             coseta[pindx]= 1.
-            pindx= (coseta < -1.)*(coseta > (-1.-10.**-7.))
-            coseta[pindx]= -1.           
+            pindx= (coseta < -1.)
+            coseta[pindx]= -1.
             eta= numpy.arccos(coseta)
             costheta= z/numpy.sqrt(R**2.+z**2.)
             sintheta= R/numpy.sqrt(R**2.+z**2.)
@@ -268,28 +265,33 @@ class actionAngleIsochrone(actionAngle):
             vzindx= (-vz*sintheta+vR*costheta) > 0.
             tan11[tan11 < 0.]+= numpy.pi
             tan12[tan12 < 0.]+= numpy.pi
-            pindx= (Lz/L > 1.)*(Lz/L < (1.+10.**-7.))
+            pindx= (Lz/L > 1.)
             Lz[pindx]= L[pindx]
-            pindx= (Lz/L < -1.)*(Lz/L > (-1.-10.**-7.))
+            pindx= (Lz/L < -1.)
             Lz[pindx]= -L[pindx]
-            i= numpy.arccos(Lz/L)
-            sinpsi= costheta/numpy.sin(i)
-            pindx= (sinpsi > 1.)*(sinpsi < (1.+10.**-7.))
+            sini= numpy.sqrt(L**2.-Lz**2.)/L
+            tani= numpy.sqrt(L**2.-Lz**2.)/Lz
+            sinpsi= costheta/sini
+            pindx= (sinpsi > 1.)*numpy.isfinite(sinpsi)
             sinpsi[pindx]= 1.
-            pindx= (sinpsi < -1.)*(sinpsi > (-1.-10.**-7.))
-            sinpsi[pindx]= -1.           
+            pindx= (sinpsi < -1.)*numpy.isfinite(sinpsi)
+            sinpsi[pindx]= -1.
             psi= numpy.arcsin(sinpsi)
             psi[vzindx]= numpy.pi-psi[vzindx]
+            # For non-inclined orbits, we set Omega=0 by convention
+            psi[True^numpy.isfinite(psi)]= phi[True^numpy.isfinite(psi)]
             psi= psi % (2.*numpy.pi)
             anglez= psi+Omegaz/Omegar*angler\
                 -tan11-1./numpy.sqrt(1.+4*self.amp*self.b/L2)*tan12
-            sinu= z/R/numpy.tan(i)
-            pindx= (sinu > 1.)*(sinu < (1.+10.**-7.))
+            sinu= z/R/tani
+            pindx= (sinu > 1.)*numpy.isfinite(sinu)
             sinu[pindx]= 1.
-            pindx= (sinu < -1.)*(sinu > (-1.-10.**-7.))
-            sinu[pindx]= -1.           
+            pindx= (sinu < -1.)*numpy.isfinite(sinu)
+            sinu[pindx]= -1.
             u= numpy.arcsin(sinu)
             u[vzindx]= numpy.pi-u[vzindx]
+            # For non-inclined orbits, we set Omega=0 by convention
+            u[True^numpy.isfinite(u)]= phi[True^numpy.isfinite(u)]
             Omega= phi-u
             anglephi= Omega
             anglephi[indx]-= anglez[indx]
