@@ -1,9 +1,10 @@
 import ctypes
 import ctypes.util
+
 import numpy
 from numpy.ctypeslib import ndpointer
-from ..util import coords
-from ..util import _load_extension_libs
+
+from ..util import _load_extension_libs, coords
 
 _lib, _ext_loaded= _load_extension_libs.load_libgalpy()
 
@@ -22,7 +23,7 @@ def actionAngleStaeckel_c(pot,delta,R,vR,vT,z,vz,u0=None,order=10):
     OUTPUT:
        (jr,jz,err)
        jr,jz : array, shape (len(R))
-       err - non-zero if error occured
+       err - non-zero if error occurred
     HISTORY:
        2012-12-01 - Written - Bovy (IAS)
     """
@@ -125,7 +126,7 @@ def actionAngleStaeckel_calcu0(E,Lz,pot,delta):
     OUTPUT:
        (u0,err)
        u0 : array, shape (len(E))
-       err - non-zero if error occured
+       err - non-zero if error occurred
     HISTORY:
        2012-12-03 - Written - Bovy (IAS)
     """
@@ -192,7 +193,7 @@ def actionAngleFreqStaeckel_c(pot,delta,R,vR,vT,z,vz,u0=None,order=10):
     NAME:
        actionAngleFreqStaeckel_c
     PURPOSE:
-       Use C to calculate actions and frequencies 
+       Use C to calculate actions and frequencies
        using the Staeckel approximation
     INPUT:
        pot - Potential or list of such instances
@@ -203,7 +204,7 @@ def actionAngleFreqStaeckel_c(pot,delta,R,vR,vT,z,vz,u0=None,order=10):
     OUTPUT:
        (jr,jz,Omegar,Omegaphi,Omegaz,err)
        jr,jz,Omegar,Omegaphi,Omegaz : array, shape (len(R))
-       err - non-zero if error occured
+       err - non-zero if error occurred
     HISTORY:
        2013-08-23 - Written - Bovy (IAS)
     """
@@ -323,7 +324,7 @@ def actionAngleFreqAngleStaeckel_c(pot,delta,R,vR,vT,z,vz,phi,
     OUTPUT:
        (jr,jz,Omegar,Omegaphi,Omegaz,Angler,Anglephi,Anglez,err)
        jr,jz,Omegar,Omegaphi,Omegaz,Angler,Anglephi,Anglez : array, shape (len(R))
-       err - non-zero if error occured
+       err - non-zero if error occurred
     HISTORY:
        2013-08-27 - Written - Bovy (IAS)
     """
@@ -436,7 +437,7 @@ def actionAngleFreqAngleStaeckel_c(pot,delta,R,vR,vT,z,vz,phi,
     if f_cont[4]: vz= numpy.asfortranarray(vz)
     if f_cont[5]: u0= numpy.asfortranarray(u0)
     if f_cont[6]: delta= numpy.asfortranarray(delta)
-    
+
     badAngle = Anglephi != 9999.99
     Anglephi[badAngle]= (Anglephi[badAngle] + phi[badAngle] % (2.*numpy.pi)) % (2.*numpy.pi)
     Anglephi[Anglephi < 0.]+= 2.*numpy.pi
@@ -457,7 +458,7 @@ def actionAngleUminUmaxVminStaeckel_c(pot,delta,R,vR,vT,z,vz,u0=None):
     OUTPUT:
        (umin,umax,vmin,err)
        umin,umax,vmin : array, shape (len(R))
-       err - non-zero if error occured
+       err - non-zero if error occurred
     HISTORY:
        2017-12-12 - Written - Bovy (UofT)
     """
@@ -548,4 +549,3 @@ def actionAngleUminUmaxVminStaeckel_c(pot,delta,R,vR,vT,z,vz,u0=None):
     if f_cont[6]: delta= numpy.asfortranarray(delta)
 
     return (umin,umax,vmin,err.value)
-
