@@ -49,10 +49,10 @@ struct JzAdiabaticArg{
   Function Declarations
 */
 EXPORT void actionAngleAdiabatic_RperiRapZmax(int,double *,double *,double *,double *,
-				       double *,int,int *,double *,double,
+				       double *,int,int *,double *,tfuncs_type_arr,double,
 				       double *,double *,double *,int *);
 EXPORT void actionAngleAdiabatic_actions(int,double *,double *,double *,double *,
-				 double *,int,int *,double *,double,
+				 double *,int,int *,double *,tfuncs_type_arr,double,
 				 double *,double *,int *);
 void calcJRAdiabatic(int,double *,double *,double *,double *,double *,
 		     int,struct potentialArg *,int);
@@ -90,7 +90,7 @@ static inline void calcEREzL(int ndata,
       + 0.5 * *(vR+ii) * *(vR+ii)
       + 0.5 * *(vT+ii) * *(vT+ii);
     *(Ez+ii)= evaluateVerticalPotentials(*(R+ii),*(z+ii),
-					 nargs,actionAngleArgs)     
+					 nargs,actionAngleArgs)
       + 0.5 * *(vz+ii) * *(vz+ii);
     *(Lz+ii)= *(R+ii) * *(vT+ii);
   }
@@ -107,6 +107,7 @@ void actionAngleAdiabatic_RperiRapZmax(int ndata,
 				       int npot,
 				       int * pot_type,
 				       double * pot_args,
+               tfuncs_type_arr pot_tfuncs,
 				       double gamma,
 				       double *rperi,
 				       double *rap,
@@ -115,7 +116,7 @@ void actionAngleAdiabatic_RperiRapZmax(int ndata,
   int ii;
   //Set up the potentials
   struct potentialArg * actionAngleArgs= (struct potentialArg *) malloc ( npot * sizeof (struct potentialArg) );
-  parse_leapFuncArgs_Full(npot,actionAngleArgs,&pot_type,&pot_args);
+  parse_leapFuncArgs_Full(npot,actionAngleArgs,&pot_type,&pot_args,&pot_tfuncs);
   //ER, Ez, Lz
   double *ER= (double *) malloc ( ndata * sizeof(double) );
   double *Ez= (double *) malloc ( ndata * sizeof(double) );
@@ -130,7 +131,7 @@ void actionAngleAdiabatic_RperiRapZmax(int ndata,
 #pragma omp parallel for schedule(static,chunk) private(ii)
   for (ii=0; ii < ndata; ii++){
     *(Lz+ii)= fabs( *(Lz+ii) ) + gamma * *(jz+ii);
-    *(ER+ii)+= 0.5 * *(Lz+ii) * *(Lz+ii) / *(R+ii) / *(R+ii) 
+    *(ER+ii)+= 0.5 * *(Lz+ii) * *(Lz+ii) / *(R+ii) / *(R+ii)
       - 0.5 * *(vT+ii) * *(vT+ii);
   }
   calcRapRperi(ndata,rperi,rap,R,ER,Lz,npot,actionAngleArgs);
@@ -150,6 +151,7 @@ void actionAngleAdiabatic_actions(int ndata,
 				  int npot,
 				  int * pot_type,
 				  double * pot_args,
+          tfuncs_type_arr pot_tfuncs,
 				  double gamma,
 				  double *jr,
 				  double *jz,
@@ -157,7 +159,7 @@ void actionAngleAdiabatic_actions(int ndata,
   int ii;
   //Set up the potentials
   struct potentialArg * actionAngleArgs= (struct potentialArg *) malloc ( npot * sizeof (struct potentialArg) );
-  parse_leapFuncArgs_Full(npot,actionAngleArgs,&pot_type,&pot_args);
+  parse_leapFuncArgs_Full(npot,actionAngleArgs,&pot_type,&pot_args,&pot_tfuncs);
   //ER, Ez, Lz
   double *ER= (double *) malloc ( ndata * sizeof(double) );
   double *Ez= (double *) malloc ( ndata * sizeof(double) );
@@ -174,7 +176,7 @@ void actionAngleAdiabatic_actions(int ndata,
 #pragma omp parallel for schedule(static,chunk) private(ii)
   for (ii=0; ii < ndata; ii++){
     *(Lz+ii)= fabs( *(Lz+ii) ) + gamma * *(jz+ii);
-    *(ER+ii)+= 0.5 * *(Lz+ii) * *(Lz+ii) / *(R+ii) / *(R+ii) 
+    *(ER+ii)+= 0.5 * *(Lz+ii) * *(Lz+ii) / *(R+ii) / *(R+ii)
       - 0.5 * *(vT+ii) * *(vT+ii);
   }
   calcRapRperi(ndata,rperi,rap,R,ER,Lz,npot,actionAngleArgs);
@@ -407,7 +409,7 @@ void calcRapRperi(int ndata,
 	  }
 	while (status == GSL_CONTINUE && iter < max_iter);
 	// LCOV_EXCL_START
-	if (status == GSL_EINVAL) {//Shouldn't ever get here 
+	if (status == GSL_EINVAL) {//Shouldn't ever get here
 	  *(rperi+ii) = -9999.99;
 	  *(rap+ii) = -9999.99;
 	  continue;
@@ -482,7 +484,7 @@ void calcRapRperi(int ndata,
 	}
       while (status == GSL_CONTINUE && iter < max_iter);
       // LCOV_EXCL_START
-      if (status == GSL_EINVAL) {//Shouldn't ever get here 
+      if (status == GSL_EINVAL) {//Shouldn't ever get here
 	*(rperi+ii) = -9999.99;
 	*(rap+ii) = -9999.99;
 	continue;
@@ -607,7 +609,7 @@ double JzAdiabaticIntegrandSquared(double z,
 						 params->actionAngleArgs);
 }
 double evaluateVerticalPotentials(double R, double z,
-				  int nargs, 
+				  int nargs,
 				  struct potentialArg * actionAngleArgs){
   return evaluatePotentials(R,z,nargs,actionAngleArgs)
     -evaluatePotentials(R,0.,nargs,actionAngleArgs);
