@@ -1,5 +1,5 @@
 ###############################################################################
-#   diskdf.py: module that interprets (E,Lz) pairs in terms of a 
+#   diskdf.py: module that interprets (E,Lz) pairs in terms of a
 #              distribution function (following Dehnen 1999)
 #
 #   This module contains the following classes:
@@ -17,26 +17,32 @@ _RMIN=10.**-10.
 _MAXD_REJECTLOS= 4.
 _PROFILE= False
 import copy
-import os, os.path
+import os
+import os.path
 import pickle
+
 import numpy
 import scipy
+
 numpylog= numpy.lib.scimath.log # somehow, this code produces log(negative), which scipy (now numpy.lib.scimath.log) implements as log(|negative|) + i pi while numpy gives NaN and we want the scipy behavior; not sure where the log(negative) comes from though! I think it's for sigma=0 DFs (this test fails with numpy.log) where the DF eval has a log(~zero) that can be slightly negative because of numerical precision issues
-from scipy import integrate, interpolate, stats, optimize
-from .surfaceSigmaProfile import surfaceSigmaProfile, expSurfaceSigmaProfile
-from ..orbit import Orbit
-from ..util.ars import ars
-from ..util import save_pickles, conversion
-from ..util.conversion import physical_conversion, \
-    potential_physical_input, surfdens_in_msolpc2
-from ..util._optional_deps import _APY_LOADED, _APY_UNITS
-from ..potential import PowerSphericalPotential
+from scipy import integrate, interpolate, optimize, stats
+
 from ..actionAngle import actionAngleAdiabatic, actionAngleAxi
+from ..orbit import Orbit
+from ..potential import PowerSphericalPotential
+from ..util import conversion, save_pickles
+from ..util._optional_deps import _APY_LOADED, _APY_UNITS
+from ..util.ars import ars
+from ..util.conversion import (physical_conversion, potential_physical_input,
+                               surfdens_in_msolpc2)
 from .df import df
+from .surfaceSigmaProfile import expSurfaceSigmaProfile, surfaceSigmaProfile
+
 if _APY_LOADED:
     from astropy import units
 #scipy version
-from pkg_resources import parse_version
+from packaging.version import parse as parse_version
+
 _SCIPY_VERSION= parse_version(scipy.__version__)
 _SCIPY_VERSION_BREAK= parse_version('0.9')
 _CORRECTIONSDIR=os.path.join(os.path.dirname(os.path.realpath(__file__)),'data')
@@ -55,8 +61,8 @@ class diskdf(df):
            Initialize a DF
         INPUT:
            dftype= 'dehnen' or 'corrected-dehnen', 'shu' or 'corrected-shu'
-           surfaceSigma - instance or class name of the target 
-                      surface density and sigma_R profile 
+           surfaceSigma - instance or class name of the target
+                      surface density and sigma_R profile
                       (default: both exponential)
            profileParams - parameters of the surface and sigma_R profile:
                       (xD,xS,Sro) where
@@ -101,7 +107,7 @@ class diskdf(df):
         self._aA= actionAngleAdiabatic(pot=PowerSphericalPotential(normalize=1.,
                                                                    alpha=2.-2.*self._beta),gamma=0.)
         return None
-    
+
     @physical_conversion('phasespacedensity2d',pop=True)
     def __call__(self,*args,**kwargs):
         """
@@ -216,7 +222,7 @@ class diskdf(df):
         if numpy.fabs(va) > sigmaR1: va = 0. #To avoid craziness near the center
         if numpy.fabs(numpy.sin(alphalos)) < numpy.sqrt(1./2.):
             cosalphalos= numpy.cos(alphalos)
-            tanalphalos= numpy.tan(alphalos)            
+            tanalphalos= numpy.tan(alphalos)
             return integrate.quad(_marginalizeVperpIntegrandSinAlphaSmall,
                                   -self._gamma*va/sigmaR1-nsigma,
                                   -self._gamma*va/sigmaR1+nsigma,
@@ -233,7 +239,7 @@ class diskdf(df):
                                   args=(self,R,sinalphalos,cotalphalos,
                                         vlos-vcirclos,vcirc,sigmaR1),
                                   **kwargs)[0]/numpy.fabs(sinalphalos)*sigmaR1
-        
+
     def _call_marginalizevlos(self,o,**kwargs):
         """Call the DF, marginalizing over line-of-sight velocity"""
         #Get d, l, vperp
@@ -241,7 +247,7 @@ class diskdf(df):
         vperp= o.vll(ro=1.,vo=1.,obs=[1.,0.,0.,0.,0.,0.])
         R= o.R(use_physical=False)
         phi= o.phi(use_physical=False)
-        #Get local circular velocity, projected onto the perpendicular 
+        #Get local circular velocity, projected onto the perpendicular
         #direction
         vcirc= R**self._beta
         vcircperp= vcirc*numpy.cos(phi+l)
@@ -281,9 +287,9 @@ class diskdf(df):
                                   args=(self,R,sinalphaperp,cotalphaperp,
                                         vperp-vcircperp,vcirc,sigmaR1),
                                   **kwargs)[0]/numpy.fabs(sinalphaperp)*sigmaR1
-        
+
     @potential_physical_input
-    @physical_conversion('velocity2',pop=True)        
+    @physical_conversion('velocity2',pop=True)
     def targetSigma2(self,R,log=False):
         """
         NAME:
@@ -312,7 +318,7 @@ class diskdf(df):
         return self._surfaceSigmaProfile.sigma2(R,log=log)
 
     @potential_physical_input
-    @physical_conversion('surfacedensity',pop=True)        
+    @physical_conversion('surfacedensity',pop=True)
     def targetSurfacemass(self,R,log=False):
          """
          NAME:
@@ -340,7 +346,7 @@ class diskdf(df):
          """
          return self._surfaceSigmaProfile.surfacemass(R,log=log)
 
-    @physical_conversion('surfacedensitydistance',pop=True)        
+    @physical_conversion('surfacedensitydistance',pop=True)
     def targetSurfacemassLOS(self,d,l,log=False,deg=True):
         """
         NAME:
@@ -386,7 +392,7 @@ class diskdf(df):
             return self._surfaceSigmaProfile.surfacemass(R,log=log)\
                 *d
 
-    @physical_conversion('surfacedensitydistance',pop=True)        
+    @physical_conversion('surfacedensitydistance',pop=True)
     def surfacemassLOS(self,d,l,deg=True,target=True,
                        romberg=False,nsigma=None,relative=None):
         """
@@ -653,7 +659,7 @@ class diskdf(df):
 
 
     @potential_physical_input
-    @physical_conversion('surfacedensity',pop=True)        
+    @physical_conversion('surfacedensity',pop=True)
     def surfacemass(self,R,romberg=False,nsigma=None,relative=False):
         """
         NAME:
@@ -789,10 +795,10 @@ class diskdf(df):
         NAME:
 
            vmomentsurfacemass
-           
+
         PURPOSE:
 
-           calculate the an arbitrary moment of the velocity distribution 
+           calculate the an arbitrary moment of the velocity distribution
            at R times the surfacmass
 
         INPUT:
@@ -842,7 +848,7 @@ class diskdf(df):
                 return out*fac
         else:
             return self._vmomentsurfacemass(*args,**kwargs)
-          
+
     def _vmomentsurfacemass(self,R,n,m,romberg=False,nsigma=None,
                            relative=False,phi=0.,deriv=None):
         """Non-physical version of vmomentsurfacemass, otherwise the same"""
@@ -1093,7 +1099,7 @@ class diskdf(df):
         return 0.5*(+meanvr/R+dmeanvphiRdphi/R+dmeanvRdR)
 
     @potential_physical_input
-    @physical_conversion('velocity2',pop=True)        
+    @physical_conversion('velocity2',pop=True)
     def sigma2(self,R,romberg=False,nsigma=None,phi=0.):
         """
         NAME:
@@ -1129,7 +1135,7 @@ class diskdf(df):
             /self.surfacemass(R,romberg,nsigma,use_physical=False)
 
     @potential_physical_input
-    @physical_conversion('velocity2',pop=True)        
+    @physical_conversion('velocity2',pop=True)
     def sigmaT2(self,R,romberg=False,nsigma=None,phi=0.):
         """
 
@@ -1170,7 +1176,7 @@ class diskdf(df):
                     /surfmass)/surfmass
 
     @potential_physical_input
-    @physical_conversion('velocity2',pop=True)        
+    @physical_conversion('velocity2',pop=True)
     def sigmaR2(self,R,romberg=False,nsigma=None,phi=0.):
         """
         NAME:
@@ -1459,7 +1465,7 @@ class diskdf(df):
         NAME:
            _ELtowRRapRperi
         PURPOSE:
-           calculate the radial frequency based on E,L, also return rap and 
+           calculate the radial frequency based on E,L, also return rap and
            rperi
         INPUT:
            E - energy
@@ -1471,7 +1477,7 @@ class diskdf(df):
         """
         if self._beta == 0.:
             xE= numpy.exp(E-.5)
-        else: #non-flat rotation curve                                      
+        else: #non-flat rotation curve
             xE= (2.*E/(1.+1./self._beta))**(1./2./self._beta)
         rperi,rap= self._aA.calcRapRperi(xE,0.,L/xE,0.,0.)
         #Replace the above w/
@@ -1498,7 +1504,7 @@ class diskdf(df):
 
            rrange - if you only want samples in this rrange, set this keyword (only works when asking for an (RZ)Orbit) (can be Quantity)
 
-           returnROrbit - if True, return a planarROrbit instance: 
+           returnROrbit - if True, return a planarROrbit instance:
                           [R,vR,vT] (default)
 
            returnOrbit - if True, return a planarOrbit instance (including phi)
@@ -1519,7 +1525,7 @@ class diskdf(df):
 
            n*nphi list of [[E,Lz],...] or list of planar(R)Orbits
 
-           CAUTION: lists of EL need to be post-processed to account for the 
+           CAUTION: lists of EL need to be post-processed to account for the
                     \kappa/\omega_R discrepancy
 
         HISTORY:
@@ -1622,8 +1628,8 @@ class dehnendf(diskdf):
         PURPOSE:
            Initialize a Dehnen 'new' DF
         INPUT:
-           surfaceSigma - instance or class name of the target 
-                      surface density and sigma_R profile 
+           surfaceSigma - instance or class name of the target
+                      surface density and sigma_R profile
                       (default: both exponential)
            profileParams - parameters of the surface and sigma_R profile:
                       (xD,xS,Sro) where
@@ -1691,7 +1697,7 @@ class dehnendf(diskdf):
         if _PROFILE: #pragma: no cover
             one_time= (time.time()-start)
             start= time.time()
-        if self._correct: 
+        if self._correct:
             correction= self._corr.correct(xE,log=True)
         else:
             correction= numpy.zeros(2)
@@ -1720,11 +1726,11 @@ class dehnendf(diskdf):
         PURPOSE:
            sample n*nphi points from this DF
         INPUT:
-           n - number of desired sample (specifying this rather than calling 
+           n - number of desired sample (specifying this rather than calling
                this routine n times is more efficient)
-           rrange - if you only want samples in this rrange, set this keyword 
+           rrange - if you only want samples in this rrange, set this keyword
                     (only works when asking for an (RZ)Orbit
-           returnROrbit - if True, return a planarROrbit instance: 
+           returnROrbit - if True, return a planarROrbit instance:
                           [R,vR,vT] (default)
            returnOrbit - if True, return a planarOrbit instance (including phi)
            nphi - number of azimuths to sample for each E,L
@@ -1736,8 +1742,8 @@ class dehnendf(diskdf):
            maxd= maximum distance to consider (for the rejection sampling)
         OUTPUT:
            n*nphi list of [[E,Lz],...] or list of planar(R)Orbits
-           CAUTION: lists of EL need to be post-processed to account for the 
-                    \kappa/\omega_R discrepancy; EL not returned in physical units        
+           CAUTION: lists of EL need to be post-processed to account for the
+                    \kappa/\omega_R discrepancy; EL not returned in physical units
         HISTORY:
            2010-07-10 - Started  - Bovy (NYU)
         """
@@ -1828,7 +1834,7 @@ class dehnendf(diskdf):
         if kwargs.get('use_physical',True) and \
                 self._roSet and self._voSet:
             if isinstance(out[0],Orbit):
-                dum= [o.turn_physical_on(ro=self._ro,vo=self._vo) for o in out]
+                dumb= [o.turn_physical_on(ro=self._ro,vo=self._vo) for o in out]
         return out
 
     def _dlnfdR(self,R,vR,vT):
@@ -1847,7 +1853,7 @@ class dehnendf(diskdf):
             dRedR= xE/2./self._beta/E*R**(2.*self._beta-1.)
         return self._dlnfdRe(R,vR,vT,E=E,xE=xE,OE=OE,LCE=LCE)*dRedR\
             +self._dlnfdl(R,vR,vT,E=E,xE=xE,OE=OE)*vT
-            
+
     def _dlnfdvR(self,R,vR,vT):
         #Calculate a bunch of stuff that we need
         if self._beta == 0.:
@@ -1863,7 +1869,7 @@ class dehnendf(diskdf):
             LCE= xE**(self._beta+1.)
             dRedvR= xE/2./self._beta/E*vR
         return self._dlnfdRe(R,vR,vT,E=E,xE=xE,OE=OE,LCE=LCE)*dRedvR
-            
+
     def _dlnfdvT(self,R,vR,vT):
         #Calculate a bunch of stuff that we need
         if self._beta == 0.:
@@ -1880,7 +1886,7 @@ class dehnendf(diskdf):
             dRedvT= xE/2./self._beta/E*vT
         return self._dlnfdRe(R,vR,vT,E=E,xE=xE,OE=OE,LCE=LCE)*dRedvT\
             +self._dlnfdl(R,vR,vT,E=E,xE=xE,OE=OE)*R
-           
+
     def _dlnfdRe(self,R,vR,vT,E=None,xE=None,OE=None,LCE=None):
         """d ln f(x,v) / d R_e"""
         #Calculate a bunch of stuff that we need
@@ -1928,18 +1934,18 @@ class shudf(diskdf):
         PURPOSE:
            Initialize a Shu DF
         INPUT:
-           surfaceSigma - instance or class name of the target 
-                      surface density and sigma_R profile 
+           surfaceSigma - instance or class name of the target
+                      surface density and sigma_R profile
                       (default: both exponential)
            profileParams - parameters of the surface and sigma_R profile:
                       (xD,xS,Sro) where
-          
+
                         xD - disk surface mass scalelength (can be Quantity)
-              
+
                         xS - disk velocity dispersion scalelength (can be Quantity)
-                        
+
                         Sro - disk velocity dispersion at Ro (can be Quantity)
-                        
+
                         Directly given to the 'surfaceSigmaProfile class, so
                         could be anything that class takes
 
@@ -1966,7 +1972,7 @@ class shudf(diskdf):
                                profileParams=profileParams,
                                correct=correct,dftype='shu',
                                beta=beta,**kwargs)
-    
+
     def eval(self,E,L,logSigmaR=0.,logsigmaR2=0.):
         """
         NAME:
@@ -1992,7 +1998,7 @@ class shudf(diskdf):
             logECLE= numpylog(-0.5*(1./self._beta+1.)*xL**(2.*self._beta)+E)
         if xL < 0.: #We must remove counter-rotating mass
             return 0.
-        if self._correct: 
+        if self._correct:
             correction= self._corr.correct(xL,log=True)
         else:
             correction= numpy.zeros(2)
@@ -2008,11 +2014,11 @@ class shudf(diskdf):
         PURPOSE:
            sample n*nphi points from this DF
         INPUT:
-           n - number of desired sample (specifying this rather than calling 
+           n - number of desired sample (specifying this rather than calling
                this routine n times is more efficient)
-           rrange - if you only want samples in this rrange, set this keyword 
+           rrange - if you only want samples in this rrange, set this keyword
                     (only works when asking for an (RZ)Orbit
-           returnROrbit - if True, return a planarROrbit instance: 
+           returnROrbit - if True, return a planarROrbit instance:
                           [R,vR,vT] (default)
            returnOrbit - if True, return a planarOrbit instance (including phi)
            nphi - number of azimuths to sample for each E,L
@@ -2024,7 +2030,7 @@ class shudf(diskdf):
            maxd= maximum distance to consider (for the rejection sampling)
         OUTPUT:
            n*nphi list of [[E,Lz],...] or list of planar(R)Orbits
-           CAUTION: lists of EL need to be post-processed to account for the 
+           CAUTION: lists of EL need to be post-processed to account for the
                     \kappa/\omega_R discrepancy
         HISTORY:
            2010-07-10 - Started  - Bovy (NYU)
@@ -2111,7 +2117,7 @@ class shudf(diskdf):
         if kwargs.get('use_physical',True) and \
                 self._roSet and self._voSet:
             if isinstance(out[0],Orbit):
-                dum= [o.turn_physical_on(ro=self._ro,vo=self._vo) for o in out]
+                dumb= [o.turn_physical_on(ro=self._ro,vo=self._vo) for o in out]
         return out
 
     def _dlnfdR(self,R,vR,vT):
@@ -2133,7 +2139,7 @@ class shudf(diskdf):
         return (self._surfaceSigmaProfile.surfacemassDerivative(xL,log=True)\
                  -(1.+(ECL-E)/sigma2xL)*self._surfaceSigmaProfile.sigma2Derivative(xL,log=True))*dRldR\
                  +dECLEdR/sigma2xL
-    
+
     def _dlnfdvR(self,R,vR,vT):
         #Calculate a bunch of stuff that we need
         E, L= vRvTRToEL(vR,vT,R,self._beta,self._dftype)
@@ -2143,7 +2149,7 @@ class shudf(diskdf):
             xL= L**(1./(self._beta+1.))
         sigma2xL= self._surfaceSigmaProfile.sigma2(xL,log=False)
         return -vR/sigma2xL
-    
+
     def _dlnfdvT(self,R,vR,vT):
         #Calculate a bunch of stuff that we need
         E, L= vRvTRToEL(vR,vT,R,self._beta,self._dftype)
@@ -2163,7 +2169,7 @@ class shudf(diskdf):
         return (self._surfaceSigmaProfile.surfacemassDerivative(xL,log=True)\
                  -(1.+(ECL-E)/sigma2xL)*self._surfaceSigmaProfile.sigma2Derivative(xL,log=True))*dRldvT\
                  +dECLEdvT/sigma2xL
-    
+
 class schwarzschilddf(shudf):
     """Schwarzschild's df"""
     def __init__(self,surfaceSigma=expSurfaceSigmaProfile,
@@ -2176,18 +2182,18 @@ class schwarzschilddf(shudf):
         PURPOSE:
            Initialize a Schwarzschild DF
         INPUT:
-           surfaceSigma - instance or class name of the target 
-                      surface density and sigma_R profile 
+           surfaceSigma - instance or class name of the target
+                      surface density and sigma_R profile
                       (default: both exponential)
            profileParams - parameters of the surface and sigma_R profile:
                       (xD,xS,Sro) where
-          
+
                         xD - disk surface mass scalelength (can be Quantity)
-              
+
                         xS - disk velocity dispersion scalelength (can be Quantity)
-                        
+
                         Sro - disk velocity dispersion at Ro (can be Quantity)
-                        
+
                         Directly given to the 'surfaceSigmaProfile class, so
                         could be anything that class takes
 
@@ -2217,7 +2223,7 @@ class schwarzschilddf(shudf):
                                profileParams=profileParams,
                                correct=correct,dftype='schwarzschild',
                                beta=beta,**kwargs)
-    
+
 
 def _surfaceIntegrand(vR,vT,R,df,logSigmaR,logsigmaR2,sigmaR1,gamma):
     """Internal function that is the integrand for the surface mass integration"""
@@ -2239,7 +2245,7 @@ def _vmomentsurfaceIntegrand(vR,vT,R,df,logSigmaR,logsigmaR2,sigmaR1,gamma,
 
 def _vmomentderivsurfaceIntegrand(vR,vT,R,df,logSigmaR,logsigmaR2,sigmaR1,
                                   gamma,n,m,deriv):
-    """Internal function that is the integrand for the derivative of velocity 
+    """Internal function that is the integrand for the derivative of velocity
     moment times surface mass integration"""
     E,L= _vRpvTpRToEL(vR,vT,R,df._beta,sigmaR1,gamma,df._dftype)
     if deriv.lower() == 'r':
@@ -2408,14 +2414,14 @@ class DFcorrection:
             return out
         else:
             return numpy.exp(out)
-            
+
 
     def derivLogcorrect(self,R):
         """
         NAME:
            derivLogcorrect
         PURPOSE:
-           calculate the derivative of the log of the correction in Sigma 
+           calculate the derivative of the log of the correction in Sigma
            and sigma2 at R
         INPUT:
            R - Galactocentric radius(/ro)
@@ -2437,10 +2443,10 @@ class DFcorrection:
                 out= numpy.array([self._surfaceInterpolate(R,nu=1)[0],
                                self._sigma2Interpolate(R,nu=1)[0]])
         return out
-            
+
 
     def _calc_corrections(self):
-        """Internal function that calculates the corrections"""     
+        """Internal function that calculates the corrections"""
         searchIter= self._niter-1
         while searchIter > 0:
             trySavefilename= self._createSavefilename(searchIter)
@@ -2481,7 +2487,7 @@ class DFcorrection:
             picklethis.append([float(a) for a in arr])
         save_pickles(self._savefilename,picklethis) #We pickle a list for platform-independence)
         return corrections
-    
+
 class DFcorrectionError(Exception):
     def __init__(self, value):
         self.value = value
@@ -2496,7 +2502,7 @@ def vRvTRToEL(vR,vT,R,beta,dftype='dehnen'):
        calculate the energy and angular momentum
     INPUT:
        vR - radial velocity
-       vT - tangential velocity
+       vT - rotational velocity
        R - Galactocentric radius
     OUTPUT:
     HISTORY:
@@ -2509,7 +2515,7 @@ def vRvTRToEL(vR,vT,R,beta,dftype='dehnen'):
         if beta == 0.:
             xL= L
         else: #non-flat rotation curve
-            xL= L**(1./(beta+1.))   
+            xL= L**(1./(beta+1.))
         return (0.5*vR**2.+0.5*gamma**2.*(vT-R**beta)**2.
                 +xL**(2.*beta)/2.+axipotential(xL,beta=beta),
                 L)
@@ -2600,7 +2606,7 @@ def _dlToRphi(d,l):
     else:
         theta= numpy.arcsin(d/R*numpy.sin(l))
     return (R,theta)
-    
+
 def _vtmaxEq(vT,R,diskdf):
     """Equation to solve to find the max vT at R"""
     #Calculate a bunch of stuff that we need
@@ -2634,4 +2640,3 @@ def _marginalizeVperpIntegrandSinAlphaSmall(vT,df,R,cosalpha,tanalpha,
                                             vlos,vcirc,sigma):
     return df(*vRvTRToEL(tanalpha*vT*sigma-vlos/cosalpha,vT*sigma+vcirc,
                         R,df._beta,df._dftype))
-
