@@ -1,19 +1,23 @@
 #A 'Binney' quasi-isothermal DF
-import warnings
 import hashlib
+import warnings
+
 import numpy
-from scipy import optimize, interpolate, integrate
-from .. import potential
-from .. import actionAngle
+from scipy import integrate, interpolate, optimize
+
+from .. import actionAngle, potential
 from ..actionAngle import actionAngleIsochrone
+from ..orbit import Orbit
 from ..potential import IsochronePotential
 from ..potential import flatten as flatten_potential
-from ..orbit import Orbit
-from .df import df, _APY_LOADED
-from ..util import galpyWarning
-from ..util.bovy_conversion import physical_conversion, \
-    potential_physical_input, actionAngle_physical_input, _APY_UNITS, \
-    physical_compatible
+from ..util import conversion, galpyWarning
+from ..util._optional_deps import _APY_LOADED, _APY_UNITS
+from ..util.conversion import (actionAngle_physical_input, parse_angmom,
+                               parse_length, parse_length_kpc, parse_velocity,
+                               parse_velocity_kms, physical_compatible,
+                               physical_conversion, potential_physical_input)
+from .df import df
+
 if _APY_LOADED:
     from astropy import units
 _NSIGMA=4
@@ -80,44 +84,30 @@ class quasiisothermaldf(df):
 
         """
         df.__init__(self,ro=ro,vo=vo)
-        if _APY_LOADED and isinstance(hr,units.Quantity):
-            hr= hr.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(sr,units.Quantity):
-            sr= sr.to(units.km/units.s).value/self._vo
-        if _APY_LOADED and isinstance(sz,units.Quantity):
-            sz= sz.to(units.km/units.s).value/self._vo
-        if _APY_LOADED and isinstance(hsr,units.Quantity):
-            hsr= hsr.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(hsz,units.Quantity):
-            hsz= hsz.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(refr,units.Quantity):
-            refr= refr.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(lo,units.Quantity):
-            lo= lo.to(units.kpc*units.km/units.s).value/self._ro/self._vo
-        self._hr= hr
-        self._sr= sr
-        self._sz= sz
-        self._hsr= hsr
-        self._hsz= hsz
-        self._refr= refr
-        self._lo= lo
+        self._hr= parse_length(hr,ro=self._ro)
+        self._sr= parse_velocity(sr,vo=self._vo)
+        self._sz= parse_velocity(sz,vo=self._vo)
+        self._hsr= parse_length(hsr,ro=self._ro)
+        self._hsz= parse_length(hsz,ro=self._ro)
+        self._refr= parse_length(refr,ro=self._ro)
+        self._lo= parse_angmom(lo,ro=self._ro,vo=self._vo)
         self._lnsr= numpy.log(self._sr)
         self._lnsz= numpy.log(self._sz)
         self._maxVT_hash= None
         self._maxVT_ip= None
         if pot is None:
-            raise IOError("pot= must be set")
+            raise OSError("pot= must be set")
         self._pot= flatten_potential(pot)
         if aA is None:
-            raise IOError("aA= must be set")
+            raise OSError("aA= must be set")
         self._aA= aA
         if not self._aA._pot == self._pot:
             if not isinstance(self._aA,actionAngleIsochrone):
-                raise IOError("Potential in aA does not appear to be the same as given potential pot")
+                raise OSError("Potential in aA does not appear to be the same as given potential pot")
             elif isinstance(self._pot,IsochronePotential) and \
                     not self._aA.b == self._pot.b and \
                     not self._aA.amp == self._pot._amp:
-                raise IOError("Potential in aA does not appear to be the same as given potential pot")
+                raise OSError("Potential in aA does not appear to be the same as given potential pot")
         self._check_consistent_units()
         self._cutcounter= cutcounter
         if _precomputerg:
@@ -193,13 +183,13 @@ class quasiisothermaldf(df):
 
         NOTE:
 
-           For Miyamoto-Nagai/adiabatic approximation this seems to take 
+           For Miyamoto-Nagai/adiabatic approximation this seems to take
            about 30 ms / evaluation in the extended Solar neighborhood
-           For a MWPotential/adiabatic approximation this takes about 
+           For a MWPotential/adiabatic approximation this takes about
            50 ms / evaluation in the extended Solar neighborhood
 
-           For adiabatic-approximation grid this seems to take 
-           about 0.67 to 0.75 ms / evaluation in the extended Solar 
+           For adiabatic-approximation grid this seems to take
+           about 0.67 to 0.75 ms / evaluation in the extended Solar
            neighborhood (includes some out of the grid)
 
            up to 200x faster when called with vector R,vR,vT,z,vz
@@ -223,12 +213,9 @@ class quasiisothermaldf(df):
         #First parse args
         if len(args) == 1 and not isinstance(args[0],Orbit): #(jr,lz,jz)
             jr,lz,jz= args[0]
-            if _APY_LOADED and isinstance(jr,units.Quantity):
-                jr= jr.to(units.kpc*units.km/units.s).value/self._ro/self._vo
-            if _APY_LOADED and isinstance(lz,units.Quantity):
-                lz= lz.to(units.kpc*units.km/units.s).value/self._ro/self._vo
-            if _APY_LOADED and isinstance(jz,units.Quantity):
-                jz= jz.to(units.kpc*units.km/units.s).value/self._ro/self._vo
+            jr= parse_angmom(jr,ro=self._ro,vo=self._vo)
+            lz= parse_angmom(lz,ro=self._ro,vo=self._vo)
+            jz= parse_angmom(jz,ro=self._ro,vo=self._vo)
         else:
             #Use self._aA to calculate the actions
             if isinstance(args[0],Orbit) and len(args[0].shape) > 1:
@@ -264,7 +251,7 @@ class quasiisothermaldf(df):
             if log:
                 funcTerm= 0.
             else:
-                funcFactor= 1.            
+                funcFactor= 1.
         if log:
             lnfsr= numpy.log(Omega)+lnsurfmass-2.*lnsr-numpy.log(numpy.pi)\
                 -numpy.log(kappa)\
@@ -459,7 +446,7 @@ class quasiisothermaldf(df):
     @physical_conversion('numbersurfacedensity',pop=True)
     def surfacemass_z(self,R,nz=7,zmax=1.,fixed_quad=True,fixed_order=8,
                       **kwargs):
-        """
+        r"""
         NAME:
 
            surfacemass_z
@@ -514,7 +501,7 @@ class quasiisothermaldf(df):
 
         PURPOSE:
 
-           calculate the an arbitrary moment of the velocity distribution 
+           calculate the an arbitrary moment of the velocity distribution
            at R times the density
 
         INPUT:
@@ -530,7 +517,7 @@ class quasiisothermaldf(df):
         OPTIONAL INPUT:
 
            nsigma - number of sigma to integrate the vR and vz velocities over (when doing explicit numerical integral; default: 4)
-           
+
            vTmax - upper limit for integration over vT (default: 1.5)
 
            mc= if True, calculate using Monte Carlo integration
@@ -558,13 +545,11 @@ class quasiisothermaldf(df):
         ro= kwargs.pop('ro',None)
         if ro is None and hasattr(self,'_roSet') and self._roSet:
             ro= self._ro
-        if _APY_LOADED and isinstance(ro,units.Quantity):
-            ro= ro.to(units.kpc).value
+        ro= parse_length_kpc(ro)
         vo= kwargs.pop('vo',None)
         if vo is None and hasattr(self,'_voSet') and self._voSet:
             vo= self._vo
-        if _APY_LOADED and isinstance(vo,units.Quantity):
-            vo= vo.to(units.km/units.s).value
+        vo= parse_velocity_kms(vo)
         if use_physical and not vo is None and not ro is None:
             fac= vo**(args[2]+args[3]+args[4])/ro**3
             if _APY_UNITS:
@@ -575,7 +560,7 @@ class quasiisothermaldf(df):
             else:
                 return out*fac
         else:
-            return self._vmomentdensity(*args,**kwargs)  
+            return self._vmomentdensity(*args,**kwargs)
 
     def _vmomentdensity(self,R,z,n,m,o,nsigma=None,mc=False,nmc=10000,
                        _returnmc=False,_vrs=None,_vts=None,_vzs=None,
@@ -750,7 +735,7 @@ class quasiisothermaldf(df):
                                      lambda x,y: 0., lambda x,y: nsigma,
                                      (R,z,self,sigmaR1,gamma,sigmaz1,n,m,o),
                                      **kwargs)[0]*sigmaR1**(2.+n+m)*gamma**(1.+m)*sigmaz1**(1.+o)
-        
+
     def jmomentdensity(self,*args,**kwargs):
         """
         NAME:
@@ -759,7 +744,7 @@ class quasiisothermaldf(df):
         PURPOSE:
 
            calculate the an arbitrary moment of an action
-           of the velocity distribution 
+           of the velocity distribution
            at R times the surfacmass
         INPUT:
 
@@ -792,13 +777,11 @@ class quasiisothermaldf(df):
         ro= kwargs.pop('ro',None)
         if ro is None and hasattr(self,'_roSet') and self._roSet:
             ro= self._ro
-        if _APY_LOADED and isinstance(ro,units.Quantity):
-            ro= ro.to(units.kpc).value
+        ro= parse_length_kpc(ro)
         vo= kwargs.pop('vo',None)
         if vo is None and hasattr(self,'_voSet') and self._voSet:
             vo= self._vo
-        if _APY_LOADED and isinstance(vo,units.Quantity):
-            vo= vo.to(units.km/units.s).value
+        vo= parse_velocity_kms(vo)
         if use_physical and not vo is None and not ro is None:
             fac= (ro*vo)**(args[2]+args[3]+args[4])/ro**3
             if _APY_UNITS:
@@ -809,7 +792,7 @@ class quasiisothermaldf(df):
             else:
                 return out*fac
         else:
-            return self._jmomentdensity(*args,**kwargs)  
+            return self._jmomentdensity(*args,**kwargs)
 
     def _jmomentdensity(self,R,z,n,m,o,nsigma=None,mc=True,nmc=10000,
                        _returnmc=False,_vrs=None,_vts=None,_vzs=None,
@@ -855,7 +838,7 @@ class quasiisothermaldf(df):
                                      lambda x,y: 0., lambda x,y: nsigma,
                                      (R,z,self,sigmaR1,gamma,sigmaz1,n,m,o),
                                      **kwargs)[0]*sigmaR1**2.*gamma*sigmaz1
-        
+
     @potential_physical_input
     @physical_conversion('numberdensity',pop=True)
     def density(self,R,z,nsigma=None,mc=False,nmc=10000,
@@ -902,7 +885,7 @@ class quasiisothermaldf(df):
                                    nsigma=nsigma,mc=mc,nmc=nmc,
                                    gl=gl,ngl=ngl,
                                    **kwargs)
-    
+
     @potential_physical_input
     @physical_conversion('velocity2',pop=True)
     def sigmaR2(self,R,z,nsigma=None,mc=False,nmc=10000,
@@ -969,7 +952,7 @@ class quasiisothermaldf(df):
                     self._vmomentdensity(R,z,0.,0.,0.,
                                             nsigma=nsigma,mc=mc,nmc=nmc,
                                             **kwargs))
-        
+
     @potential_physical_input
     @physical_conversion('velocity2',pop=True)
     def sigmaRz(self,R,z,nsigma=None,mc=False,nmc=10000,
@@ -1036,7 +1019,7 @@ class quasiisothermaldf(df):
                     self._vmomentdensity(R,z,0.,0.,0.,
                                             nsigma=nsigma,mc=mc,nmc=nmc,
                                             **kwargs))
-        
+
     @potential_physical_input
     @physical_conversion('angle',pop=True)
     def tilt(self,R,z,nsigma=None,mc=False,nmc=10000,
@@ -1119,7 +1102,7 @@ class quasiisothermaldf(df):
             return 0.5*numpy.arctan(2.*tsigmarz/(tsigmar2-tsigmaz2))
         else:
             raise NotImplementedError("Use either mc=True or gl=True")
-        
+
     @potential_physical_input
     @physical_conversion('velocity2',pop=True)
     def sigmaz2(self,R,z,nsigma=None,mc=False,nmc=10000,
@@ -1186,7 +1169,7 @@ class quasiisothermaldf(df):
                     self._vmomentdensity(R,z,0.,0.,0.,
                                             nsigma=nsigma,mc=mc,nmc=nmc,
                                             **kwargs))
-        
+
     @potential_physical_input
     @physical_conversion('velocity',pop=True)
     def meanvT(self,R,z,nsigma=None,mc=False,nmc=10000,
@@ -1198,7 +1181,7 @@ class quasiisothermaldf(df):
 
         PURPOSE:
 
-           calculate the mean rotational velocity by marginalizing over velocity 
+           calculate the mean rotational velocity by marginalizing over velocity
 
         INPUT:
 
@@ -1253,7 +1236,7 @@ class quasiisothermaldf(df):
                     self._vmomentdensity(R,z,0.,0.,0.,
                                             nsigma=nsigma,mc=mc,nmc=nmc,
                                             **kwargs))
-        
+
     @potential_physical_input
     @physical_conversion('velocity',pop=True)
     def meanvR(self,R,z,nsigma=None,mc=False,nmc=10000,
@@ -1320,7 +1303,7 @@ class quasiisothermaldf(df):
                     self._vmomentdensity(R,z,0.,0.,0.,
                                             nsigma=nsigma,mc=mc,nmc=nmc,
                                             **kwargs))
-        
+
     @potential_physical_input
     @physical_conversion('velocity',pop=True)
     def meanvz(self,R,z,nsigma=None,mc=False,nmc=10000,
@@ -1387,7 +1370,7 @@ class quasiisothermaldf(df):
                     self._vmomentdensity(R,z,0.,0.,0.,
                                             nsigma=nsigma,mc=mc,nmc=nmc,
                                             **kwargs))
-        
+
     @potential_physical_input
     @physical_conversion('velocity2',pop=True)
     def sigmaT2(self,R,z,nsigma=None,mc=False,nmc=10000,
@@ -1520,7 +1503,7 @@ class quasiisothermaldf(df):
                     self._vmomentdensity(R,z,0.,0.,0.,
                                             nsigma=nsigma,mc=mc,nmc=nmc,
                                             **kwargs))
-        
+
     @potential_physical_input
     @physical_conversion('action',pop=True)
     def meanlz(self,R,z,nsigma=None,mc=True,nmc=10000,**kwargs):
@@ -1573,7 +1556,7 @@ class quasiisothermaldf(df):
                     self._vmomentdensity(R,z,0.,0.,0.,
                                             nsigma=nsigma,mc=mc,nmc=nmc,
                                             **kwargs))
-        
+
     @potential_physical_input
     @physical_conversion('action',pop=True)
     def meanjz(self,R,z,nsigma=None,mc=True,nmc=10000,**kwargs):
@@ -1626,7 +1609,7 @@ class quasiisothermaldf(df):
                     self._vmomentdensity(R,z,0.,0.,0.,
                                             nsigma=nsigma,mc=mc,nmc=nmc,
                                             **kwargs))
-        
+
     @potential_physical_input
     def sampleV(self,R,z,n=1,**kwargs):
         """
@@ -1659,14 +1642,16 @@ class quasiisothermaldf(df):
         vo= kwargs.pop('vo',None)
         if vo is None and hasattr(self,'_voSet') and self._voSet:
             vo= self._vo
-        if _APY_LOADED and isinstance(vo,units.Quantity):
-            vo= vo.to(units.km/units.s).value
+        vo= parse_velocity_kms(vo)
         #Determine the maximum of the velocity distribution
         maxVR= 0.
         maxVz= 0.
-        maxVT= optimize.fmin_powell((lambda x: -self(R,0.,x,z,0.,log=True,
+        # scipy 1.5.0: issue scipy#12298: fmin_powell now returns multiD array,
+        # so squeeze out single dimensions by hand
+        maxVT= numpy.squeeze(\
+                             optimize.fmin_powell((lambda x: -self(R,0.,x,z,0.,log=True,
                                                      use_physical=False)),
-                                    1.)
+                                    1.))
         logmaxVD= self(R,maxVR,maxVT,z,maxVz,log=True,use_physical=False)
         #Now rejection-sample
         vRs= []
@@ -1705,44 +1690,43 @@ class quasiisothermaldf(df):
                             R_max=None,z_max=None,**kwargs):
         """
         NAME:
-            
+
             sampleV_interpolate
-    
+
         PURPOSE:
-            
-            Given an array of R and z coordinates of stars, return the 
+
+            Given an array of R and z coordinates of stars, return the
             positions and their radial, azimuthal, and vertical velocity.
-    
+
         INPUT:
-            
+
             R - array of Galactocentric distance (can be Quantity)
 
             z - array of height (can be Quantity)
-            
+
             R_pixel, z_pixel= the pixel size for creating the grid for
                    interpolation (in natural unit)
-            
+
             num_std= number of standard deviation to be considered outliers
                       sampled separately from interpolation
-                      
+
             R_min, R_max, z_max= optional edges of the grid
-    
+
         OUTPUT:
-            
+
             coord_v= a numpy array containing the sampled velocity, (vR, vT, vz),
                      where each row correspond to the row of (R,z)
-    
+
         HISTORY:
-            
+
             2018-08-10 - Written - Samuel Wong (University of Toronto)
-            
+
         """
         use_physical= kwargs.pop('use_physical',True)
         vo= kwargs.pop('vo',None)
         if vo is None and hasattr(self,'_voSet') and self._voSet:
             vo= self._vo
-        if _APY_LOADED and isinstance(vo,units.Quantity):
-            vo= vo.to(units.km/units.s).value
+        vo= parse_velocity_kms(vo)
         #Initialize output array
         coord_v= numpy.empty((numpy.size(R), 3))
         #Since the sign of z doesn't matter, work with absolute value of z
@@ -1758,7 +1742,7 @@ class quasiisothermaldf(df):
             z_max= numpy.amin([numpy.mean(z)+num_std*numpy.std(z),
                                numpy.amax(z)])
         z_min= 0. #Always start grid at z=0 for stars close to plane
-        #Separate the coodinates into outliers and normal points
+        #Separate the coordinates into outliers and normal points
         #Define outliers as points outside of grid
         mask= numpy.any([R < R_min, R > R_max, z > z_max],axis = 0)
         outliers_R= R[mask]
@@ -1784,15 +1768,17 @@ class quasiisothermaldf(df):
             z_linspace= numpy.linspace(z_min, z_max, z_number)
             Rv, zv= numpy.meshgrid(R_linspace, z_linspace)
             grid= numpy.dstack((Rv, zv)) #This grid stores (R,z) coordinate
-            #Grid is a 3 dimensional array since it stores pairs of values, but 
-            #grid max vT is a 2 dimensinal array
+            #Grid is a 3 dimensional array since it stores pairs of values, but
+            #grid max vT is a 2 dimensional array
             grid_max_vT= numpy.empty((grid.shape[0], grid.shape[1]))
             #Optimize max_vT on the grid
             for i in range(z_number):
                 for j in range(R_number):
                     R, z= grid[i][j]
-                    grid_max_vT[i][j]= optimize.fmin_powell((lambda x: -self(
-                            R,0.,x,z,0.,log=True, use_physical=False)),1.)
+                    grid_max_vT[i][j]= numpy.squeeze(\
+                                        optimize.fmin_powell((lambda x: -self(
+                                            R,0.,x,z,0.,log=True,
+                                            use_physical=False)),1.))
             #Determine degree of interpolation
             ky= numpy.min([R_number-1,3])
             kx= numpy.min([z_number-1,3])
@@ -1835,7 +1821,7 @@ class quasiisothermaldf(df):
            R - Galactocentric distance (can be Quantity)
 
            z - height (can be Quantity)
-           
+
            maxVT - an array of pre-optimized maximum vT at corresponding R,z
 
         OUTPUT:
@@ -1855,7 +1841,7 @@ class quasiisothermaldf(df):
         maxVz= numpy.zeros(length)
         logmaxVD= self(R,maxVR,maxVT,z,maxVz,log=True,use_physical=False)
         #Now rejection-sample
-        #Intiialize boolean index of position remaining to be sampled
+        #Initialize boolean index of position remaining to be sampled
         remain_indx = numpy.full(length,True)
         while numpy.any(remain_indx):
             nmore= numpy.sum(remain_indx)
@@ -1979,7 +1965,7 @@ class quasiisothermaldf(df):
 
         INPUT:
 
-           vT - tangential velocity (can be Quantity)
+           vT - rotational velocity (can be Quantity)
 
            R - radius (can be Quantity)
 
@@ -2211,7 +2197,7 @@ class quasiisothermaldf(df):
             if _return_actions and _return_freqs:
                 return (result,
                         jr,lz,jz,
-                        rg, kappa, nu, Omega)          
+                        rg, kappa, nu, Omega)
             elif _return_freqs:
                 return (result,
                         rg, kappa, nu, Omega)
@@ -2237,7 +2223,7 @@ class quasiisothermaldf(df):
 
            vR - radial velocity (can be Quantity)
 
-           vT - tangential velocity (can be Quantity)
+           vT - rotational velocity (can be Quantity)
 
            R - radius (can be Quantity)
 
@@ -2246,7 +2232,7 @@ class quasiisothermaldf(df):
            gl - use Gauss-Legendre integration (True, currently the only option)
 
            ngl - order of Gauss-Legendre integration
-           
+
            nsigma - sets integration limits to [-1,+1]*nsigma*sigma_z(R) for integration over vz (default: 4)
 
         OUTPUT:
@@ -2255,7 +2241,7 @@ class quasiisothermaldf(df):
 
         HISTORY:
 
-           2013-01-02 - Written - Bovy (IAS)           
+           2013-01-02 - Written - Bovy (IAS)
            2018-01-12 - Added Gauss-Legendre integration prefactor nsigma/2 - Trick (MPA)
 
         """
@@ -2312,7 +2298,7 @@ class quasiisothermaldf(df):
 
         INPUT:
 
-           vT - tangential velocity (can be Quantity)
+           vT - rotational velocity (can be Quantity)
 
            vz - vertical velocity (can be Quantity)
 
@@ -2323,7 +2309,7 @@ class quasiisothermaldf(df):
            gl - use Gauss-Legendre integration (True, currently the only option)
 
            ngl - order of Gauss-Legendre integration
-           
+
            nsigma - sets integration limits to [-1,+1]*nsigma*sigma_R(R) for integration over vR (default: 4)
 
         OUTPUT:
@@ -2332,7 +2318,7 @@ class quasiisothermaldf(df):
 
         HISTORY:
 
-           2012-12-22 - Written - Bovy (IAS)           
+           2012-12-22 - Written - Bovy (IAS)
            2018-01-12 - Added Gauss-Legendre integration prefactor nsigma/2 - Trick (MPA)
 
         """
@@ -2400,7 +2386,7 @@ class quasiisothermaldf(df):
            gl - use Gauss-Legendre integration (True, currently the only option)
 
            ngl - order of Gauss-Legendre integration
-           
+
            vTmax - sets integration limits to [0,vTmax] for integration over vT (default: 1.5)
 
         OUTPUT:
@@ -2507,7 +2493,7 @@ class quasiisothermaldf(df):
         HISTORY:
            2012-07-25 - Written - Bovy (IAS@MPIA)
         NOTE:
-           seems to take about ~0.5 ms for a Miyamoto-Nagai potential; 
+           seems to take about ~0.5 ms for a Miyamoto-Nagai potential;
            ~0.75 ms for a MWPotential
            about the same with or without interpolation of the rotation curve
 
