@@ -1,18 +1,23 @@
-import warnings
 import ctypes
 import ctypes.util
-from numpy.ctypeslib import ndpointer
+import warnings
+
 import numpy
+from numpy.ctypeslib import ndpointer
 from scipy import integrate
+
 from .. import potential
-from ..util import galpyWarning
-from ..potential.Potential import _evaluateRforces, _evaluatezforces,\
-    _evaluatephiforces
-from .integratePlanarOrbit import _parse_integrator, _parse_tol
-from ..util.multi import parallel_map
+from ..potential.Potential import (_evaluatephitorques, _evaluateRforces,
+                                   _evaluatezforces)
+from ..util import _load_extension_libs, galpyWarning, symplecticode
+from ..util._optional_deps import _TQDM_LOADED
 from ..util.leung_dop853 import dop853
-from ..util import bovy_symplecticode as symplecticode
-from ..util import _load_extension_libs
+from ..util.multi import parallel_map
+from .integratePlanarOrbit import (_parse_integrator, _parse_scf_pot,
+                                   _parse_tol, _prep_tfuncs)
+
+if _TQDM_LOADED:
+    import tqdm
 
 _lib, _ext_loaded= _load_extension_libs.load_libgalpy()
 
@@ -21,9 +26,18 @@ def _parse_pot(pot,potforactions=False,potfortorus=False):
     #Figure out what's in pot
     if not isinstance(pot,list):
         pot= [pot]
+    if (potforactions or potfortorus) \
+        and ( (len(pot) == 1 and isinstance(pot[0],potential.NullPotential))
+             or numpy.all([isinstance(p,potential.NullPotential) for p in pot]) ):
+        raise NotImplementedError("Evaluating actions using the C backend is not supported for NullPotential instances")
+    # Remove NullPotentials from list of Potentials containing other potentials
+    purged_pot= [p for p in pot if not isinstance(p,potential.NullPotential)]
+    if len(purged_pot) > 0:
+        pot= purged_pot
     #Initialize everything
     pot_type= []
     pot_args= []
+    pot_tfuncs= []
     npot= len(pot)
     for p in pot:
         if isinstance(p,potential.LogarithmicHaloPotential):
@@ -53,15 +67,12 @@ def _parse_pot(pot,potforactions=False,potfortorus=False):
             pot_args.extend([p._amp,p.a])
         elif isinstance(p,potential.DoubleExponentialDiskPotential):
             pot_type.append(11)
-            pot_args.extend([p._amp,p._alpha,p._beta,p._kmaxFac,
-                             p._nzeros,p._glorder])
-            pot_args.extend([p._glx[ii] for ii in range(p._glorder)])
-            pot_args.extend([p._glw[ii] for ii in range(p._glorder)])
-            pot_args.extend([p._j0zeros[ii] for ii in range(p._nzeros+1)])
-            pot_args.extend([p._dj0zeros[ii] for ii in range(p._nzeros+1)])
-            pot_args.extend([p._j1zeros[ii] for ii in range(p._nzeros+1)])
-            pot_args.extend([p._dj1zeros[ii] for ii in range(p._nzeros+1)])
-            pot_args.extend([p._kp._amp,p._kp.alpha])
+            pot_args.extend([p._amp,-4.*numpy.pi*p._alpha*p._amp,
+                             p._alpha,p._beta,len(p._de_j1_xs)])
+            pot_args.extend(p._de_j0_xs)
+            pot_args.extend(p._de_j1_xs)
+            pot_args.extend(p._de_j0_weights)
+            pot_args.extend(p._de_j1_weights)
         elif isinstance(p,potential.FlattenedPowerPotential):
             pot_type.append(12)
             pot_args.extend([p._amp,p.alpha,p.q2,p.core2])
@@ -139,6 +150,12 @@ def _parse_pot(pot,potforactions=False,potfortorus=False):
             elif isinstance(p,potential.PerfectEllipsoidPotential):
                 pot_type.append(30)
                 pot_args.extend([1,p.a2]) # for psi, mdens, mdens_deriv
+            elif isinstance(p,potential.TriaxialGaussianPotential):
+                pot_type.append(37)
+                pot_args.extend([1,-p._twosigma2]) # for psi, mdens, mdens_deriv
+            elif isinstance(p,potential.PowerTriaxialPotential):
+                pot_type.append(38)
+                pot_args.extend([1,p.alpha]) # for psi, mdens, mdens_deriv
             pot_args.extend([p._b2,p._c2,int(p._aligned)]) # Reg. Ellipsoidal
             if not p._aligned:
                 pot_args.extend(list(p._rot.flatten()))
@@ -153,9 +170,10 @@ def _parse_pot(pot,potforactions=False,potfortorus=False):
                              for ii in range(p._glorder)])
         elif isinstance(p,potential.SCFPotential):
             # Type 24, see stand-alone parser below
-            pt,pa= _parse_scf_pot(p)
+            pt,pa,ptf= _parse_scf_pot(p)
             pot_type.append(pt)
             pot_args.extend(pa)
+            pot_tfuncs.extend(ptf)
         elif isinstance(p,potential.SoftenedNeedleBarPotential):
             pot_type.append(25)
             pot_args.extend([p._amp,p._a,p._b,p._c2,p._pa,p._omegab])
@@ -164,9 +182,10 @@ def _parse_pot(pot,potforactions=False,potfortorus=False):
             # Need to pull this apart into: (a) SCF part, (b) constituent
             # [Sigma_i,h_i] parts
             # (a) SCF, multiply in any add'l amp
-            pt,pa= _parse_scf_pot(p._scf,extra_amp=p._amp)
+            pt,pa,ptf= _parse_scf_pot(p._scf,extra_amp=p._amp)
             pot_type.append(pt)
             pot_args.extend(pa)
+            pot_tfuncs.extend(ptf)
             # (b) constituent [Sigma_i,h_i] parts
             for Sigma,hz in zip(p._Sigma_dict,p._hz_dict):
                 npot+= 1
@@ -204,53 +223,101 @@ def _parse_pot(pot,potforactions=False,potfortorus=False):
         elif isinstance(p,potential.HomogeneousSpherePotential):
             pot_type.append(35)
             pot_args.extend([p._amp,p._R2,p._R3])
+        elif isinstance(p,potential.interpSphericalPotential):
+            pot_type.append(36)
+            pot_args.append(len(p._rgrid))
+            pot_args.extend(p._rgrid)
+            pot_args.extend(p._rforce_grid)
+            pot_args.extend([p._amp,p._rmin,p._rmax,p._total_mass,
+                             p._Phi0,p._Phimax])
+        # 37: TriaxialGaussianPotential, done with others above
+        # 38: PowerTriaxialPotential, done with others above
+        elif isinstance(p,potential.NonInertialFrameForce):
+            pot_type.append(39)
+            pot_args.append(p._amp)
+            pot_args.extend([0.,0.,0.,0.,0.,0.,0.,0.,0.,0.]) # for caching
+            pot_args.extend([p._rot_acc,p._lin_acc,p._omegaz_only,
+                             p._const_freq,p._Omega_as_func])
+            if p._Omega_as_func:
+                pot_args.extend([0.,0.,0.,0.,0.,0.,0.])
+            else:
+                if p._omegaz_only:
+                    pot_args.extend([0.,0.,p._Omega])
+                else:
+                    pot_args.extend(p._Omega)
+                pot_args.append(p._Omega2)
+                if not p._const_freq and p._omegaz_only:
+                    pot_args.extend([0.,0.,p._Omegadot])
+                elif not p._const_freq:
+                    pot_args.extend(p._Omegadot)
+                else:
+                    pot_args.extend([0.,0.,0.])
+            if p._lin_acc:
+                pot_tfuncs.extend([p._a0[0],p._a0[1],p._a0[2]])
+                if p._rot_acc:
+                    pot_tfuncs.extend([p._x0[0],p._x0[1],p._x0[2]])
+                    pot_tfuncs.extend([p._v0[0],p._v0[1],p._v0[2]])
+            if p._Omega_as_func:
+                if p._omegaz_only:
+                    pot_tfuncs.extend([p._Omega,p._Omegadot])
+                else:
+                    pot_tfuncs.extend([p._Omega[0],p._Omega[1],p._Omega[2],
+                                       p._Omegadot[0],p._Omegadot[1],p._Omegadot[2]])
+        elif isinstance(p,potential.NullPotential):
+            pot_type.append(40)
+            # No arguments, zero forces
         ############################## WRAPPERS ###############################
         elif isinstance(p,potential.DehnenSmoothWrapperPotential):
             pot_type.append(-1)
-            wrap_npot, wrap_pot_type, wrap_pot_args= \
+            wrap_npot, wrap_pot_type, wrap_pot_args, wrap_pot_tfuncs= \
                 _parse_pot(p._pot,
                            potforactions=potforactions,potfortorus=potfortorus)
             pot_args.append(wrap_npot)
             pot_type.extend(wrap_pot_type)
             pot_args.extend(wrap_pot_args)
+            pot_tfuncs.extend(wrap_pot_tfuncs)
             pot_args.extend([p._amp,p._tform,p._tsteady,int(p._grow)])
         elif isinstance(p,potential.SolidBodyRotationWrapperPotential):
             pot_type.append(-2)
             # Not sure how to easily avoid this duplication
-            wrap_npot, wrap_pot_type, wrap_pot_args= \
+            wrap_npot, wrap_pot_type, wrap_pot_args, wrap_pot_tfuncs= \
                 _parse_pot(p._pot,
                            potforactions=potforactions,potfortorus=potfortorus)
             pot_args.append(wrap_npot)
             pot_type.extend(wrap_pot_type)
             pot_args.extend(wrap_pot_args)
+            pot_tfuncs.extend(wrap_pot_tfuncs)
             pot_args.extend([p._amp,p._omega,p._pa])
         elif isinstance(p,potential.CorotatingRotationWrapperPotential):
             pot_type.append(-4)
             # Not sure how to easily avoid this duplication
-            wrap_npot, wrap_pot_type, wrap_pot_args= \
+            wrap_npot, wrap_pot_type, wrap_pot_args, wrap_pot_tfuncs= \
                 _parse_pot(p._pot,
                            potforactions=potforactions,potfortorus=potfortorus)
             pot_args.append(wrap_npot)
             pot_type.extend(wrap_pot_type)
             pot_args.extend(wrap_pot_args)
+            pot_tfuncs.extend(wrap_pot_tfuncs)
             pot_args.extend([p._amp,p._vpo,p._beta,p._pa,p._to])
         elif isinstance(p,potential.GaussianAmplitudeWrapperPotential):
             pot_type.append(-5)
-            wrap_npot, wrap_pot_type, wrap_pot_args= \
+            wrap_npot, wrap_pot_type, wrap_pot_args, wrap_pot_tfuncs= \
                 _parse_pot(p._pot,
                            potforactions=potforactions,potfortorus=potfortorus)
             pot_args.append(wrap_npot)
             pot_type.extend(wrap_pot_type)
             pot_args.extend(wrap_pot_args)
+            pot_tfuncs.extend(wrap_pot_tfuncs)
             pot_args.extend([p._amp,p._to,p._sigma2])
         elif isinstance(p,potential.MovingObjectPotential):
             pot_type.append(-6)
-            wrap_npot, wrap_pot_type, wrap_pot_args= \
+            wrap_npot, wrap_pot_type, wrap_pot_args, wrap_pot_tfuncs= \
                 _parse_pot(p._pot,
                            potforactions=potforactions,potfortorus=potfortorus)
             pot_args.append(wrap_npot)
             pot_type.extend(wrap_pot_type)
             pot_args.extend(wrap_pot_args)
+            pot_tfuncs.extend(wrap_pot_tfuncs)
             pot_args.extend([len(p._orb.t)])
             pot_args.extend(p._orb.t)
             pot_args.extend(p._orb.x(p._orb.t,use_physical=False))
@@ -260,12 +327,13 @@ def _parse_pot(pot,potforactions=False,potfortorus=False):
             pot_args.extend([p._orb.t[0],p._orb.t[-1]]) #t_0, t_f
         elif isinstance(p,potential.ChandrasekharDynamicalFrictionForce):
             pot_type.append(-7)
-            wrap_npot, wrap_pot_type, wrap_pot_args= \
+            wrap_npot, wrap_pot_type, wrap_pot_args, wrap_pot_tfuncs= \
                 _parse_pot(p._dens_pot,
                            potforactions=potforactions,potfortorus=potfortorus)
             pot_args.append(wrap_npot)
             pot_type.extend(wrap_pot_type)
             pot_args.extend(wrap_pot_args)
+            pot_tfuncs.extend(wrap_pot_tfuncs)
             pot_args.extend([len(p._sigmar_rs_4interp)])
             pot_args.extend(p._sigmar_rs_4interp)
             pot_args.extend(p._sigmars_4interp)
@@ -276,22 +344,40 @@ def _parse_pot(pot,potforactions=False,potfortorus=False):
                              p._minr**2.])
             pot_args.extend([p._sigmar_rs_4interp[0],
                              p._sigmar_rs_4interp[-1]]) #r_0, r_f
+        elif isinstance(p,potential.RotateAndTiltWrapperPotential):
+            pot_type.append(-8)
+            # Not sure how to easily avoid this duplication
+            wrap_npot, wrap_pot_type, wrap_pot_args, wrap_pot_tfuncs= \
+                _parse_pot(p._pot,
+                           potforactions=potforactions,potfortorus=potfortorus)
+            pot_args.append(wrap_npot)
+            pot_type.extend(wrap_pot_type)
+            pot_args.extend(wrap_pot_args)
+            pot_tfuncs.extend(wrap_pot_tfuncs)
+            pot_args.extend([p._amp])
+            pot_args.extend([0.,0.,0.,0.,0.,0.]) # for caching
+            pot_args.extend(list(p._rot.flatten()))
+            pot_args.append(not p._norot)
+            pot_args.append(not p._offset is None)
+            pot_args.extend(list(p._offset) if not p._offset is None else [0.,0.,0.])
+        elif isinstance(p,potential.TimeDependentAmplitudeWrapperPotential):
+            pot_type.append(-9)
+            # Not sure how to easily avoid this duplication
+            wrap_npot, wrap_pot_type, wrap_pot_args, wrap_pot_tfuncs= \
+                _parse_pot(p._pot,
+                           potforactions=potforactions,potfortorus=potfortorus)
+            pot_args.append(wrap_npot)
+            pot_type.extend(wrap_pot_type)
+            pot_args.extend(wrap_pot_args)
+            pot_tfuncs.extend(wrap_pot_tfuncs)
+            pot_args.append(p._amp)
+            pot_tfuncs.append(p._A)
     pot_type= numpy.array(pot_type,dtype=numpy.int32,order='C')
     pot_args= numpy.array(pot_args,dtype=numpy.float64,order='C')
-    return (npot,pot_type,pot_args)
+    return (npot,pot_type,pot_args,pot_tfuncs)
 
-def _parse_scf_pot(p,extra_amp=1.):
-    # Stand-alone parser for SCF, bc re-used
-    isNonAxi= p.isNonAxi
-    pot_args= [p._a, isNonAxi]
-    pot_args.extend(p._Acos.shape)
-    pot_args.extend(extra_amp*p._amp*p._Acos.flatten(order='C'))
-    if isNonAxi:
-        pot_args.extend(extra_amp*p._amp*p._Asin.flatten(order='C'))   
-    pot_args.extend([-1.,0,0,0,0,0,0])    
-    return (24,pot_args)
-
-def integrateFullOrbit_c(pot,yo,t,int_method,rtol=None,atol=None,dt=None):
+def integrateFullOrbit_c(pot,yo,t,int_method,rtol=None,atol=None,
+                         progressbar=True,dt=None):
     """
     NAME:
        integrateFullOrbit_c
@@ -303,6 +389,7 @@ def integrateFullOrbit_c(pot,yo,t,int_method,rtol=None,atol=None,dt=None):
        t - set of times at which one wants the result
        int_method= 'leapfrog_c', 'rk4_c', 'rk6_c', 'symplec4_c'
        rtol, atol
+       progressbar= (True) if True, display a tqdm progress bar when integrating multiple orbits (requires tqdm to be installed!)
        dt= (None) force integrator to use this stepsize (default is to automatically determine one; only for C-based integrators)
     OUTPUT:
        (y,err)
@@ -313,37 +400,50 @@ def integrateFullOrbit_c(pot,yo,t,int_method,rtol=None,atol=None,dt=None):
     HISTORY:
        2011-11-13 - Written - Bovy (IAS)
        2018-12-21 - Adapted to allow multiple objects - Bovy (UofT)
+       2022-04-12 - Add progressbar - Bovy (UofT)
     """
     if len(yo.shape) == 1: single_obj= True
     else: single_obj= False
     yo= numpy.atleast_2d(yo)
     nobj= len(yo)
     rtol, atol= _parse_tol(rtol,atol)
-    npot, pot_type, pot_args= _parse_pot(pot)
+    npot, pot_type, pot_args, pot_tfuncs= _parse_pot(pot)
+    pot_tfuncs= _prep_tfuncs(pot_tfuncs)
     int_method_c= _parse_integrator(int_method)
-    if dt is None: 
+    if dt is None:
         dt= -9999.99
 
     #Set up result array
     result= numpy.empty((nobj,len(t),6))
     err= numpy.zeros(nobj,dtype=numpy.int32)
 
+    #Set up progressbar
+    progressbar*= _TQDM_LOADED
+    if nobj > 1 and progressbar:
+        pbar= tqdm.tqdm(total=nobj,leave=False)
+        pbar_func_ctype= ctypes.CFUNCTYPE(None)
+        pbar_c= pbar_func_ctype(pbar.update)
+    else: # pragma: no cover
+        pbar_c= None
+
     #Set up the C code
     ndarrayFlags= ('C_CONTIGUOUS','WRITEABLE')
     integrationFunc= _lib.integrateFullOrbit
     integrationFunc.argtypes= [ctypes.c_int,
                                ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
-                               ctypes.c_int,                             
+                               ctypes.c_int,
                                ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
                                ctypes.c_int,
                                ndpointer(dtype=numpy.int32,flags=ndarrayFlags),
                                ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
+                               ctypes.c_void_p,
                                ctypes.c_double,
                                ctypes.c_double,
                                ctypes.c_double,
                                ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
                                ndpointer(dtype=numpy.int32,flags=ndarrayFlags),
-                               ctypes.c_int]
+                               ctypes.c_int,
+                               ctypes.c_void_p]
 
     #Array requirements, first store old order
     f_cont= [yo.flags['F_CONTIGUOUS'],
@@ -361,13 +461,18 @@ def integrateFullOrbit_c(pot,yo,t,int_method,rtol=None,atol=None,dt=None):
                     ctypes.c_int(npot),
                     pot_type,
                     pot_args,
+                    pot_tfuncs,
                     ctypes.c_double(dt),
                     ctypes.c_double(rtol),
                     ctypes.c_double(atol),
                     result,
                     err,
-                    ctypes.c_int(int_method_c))
-    
+                    ctypes.c_int(int_method_c),
+                    pbar_c)
+
+    if nobj > 1 and progressbar:
+        pbar.close()
+
     if numpy.any(err == -10): #pragma: no cover
         raise KeyboardInterrupt("Orbit integration interrupted by CTRL-C (SIGINT)")
 
@@ -401,7 +506,8 @@ def integrateFullOrbit_dxdv_c(pot,yo,dyo,t,int_method,rtol=None,atol=None): #pra
        2011-11-13 - Written - Bovy (IAS)
     """
     rtol, atol= _parse_tol(rtol,atol)
-    npot, pot_type, pot_args= _parse_pot(pot)
+    npot, pot_type, pot_args, pot_tfuncs= _parse_pot(pot)
+    pot_tfuncs= _prep_tfuncs(pot_tfuncs)
     int_method_c= _parse_integrator(int_method)
     yo= numpy.concatenate((yo,dyo))
 
@@ -413,11 +519,12 @@ def integrateFullOrbit_dxdv_c(pot,yo,dyo,t,int_method,rtol=None,atol=None): #pra
     ndarrayFlags= ('C_CONTIGUOUS','WRITEABLE')
     integrationFunc= _lib.integrateFullOrbit_dxdv
     integrationFunc.argtypes= [ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
-                               ctypes.c_int,                             
+                               ctypes.c_int,
                                ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
                                ctypes.c_int,
                                ndpointer(dtype=numpy.int32,flags=ndarrayFlags),
                                ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
+                               ctypes.c_void_p,
                                ctypes.c_double,
                                ctypes.c_double,
                                ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
@@ -438,6 +545,7 @@ def integrateFullOrbit_dxdv_c(pot,yo,dyo,t,int_method,rtol=None,atol=None): #pra
                     ctypes.c_int(npot),
                     pot_type,
                     pot_args,
+                    pot_tfuncs,
                     ctypes.c_double(rtol),ctypes.c_double(atol),
                     result,
                     ctypes.byref(err),
@@ -452,8 +560,8 @@ def integrateFullOrbit_dxdv_c(pot,yo,dyo,t,int_method,rtol=None,atol=None): #pra
 
     return (result,err.value)
 
-def integrateFullOrbit(pot,yo,t,int_method,rtol=None,atol=None,numcores=1,
-                       dt=None):
+def integrateFullOrbit(pot,yo,t,int_method,rtol=None,atol=None,
+                       numcores=1,progressbar=True,dt=None):
     """
     NAME:
        integrateFullOrbit
@@ -466,6 +574,7 @@ def integrateFullOrbit(pot,yo,t,int_method,rtol=None,atol=None,numcores=1,
        int_method= 'leapfrog', 'odeint', or 'dop853'
        rtol, atol= tolerances (not always used...)
        numcores= (1) number of cores to use for multi-processing
+       progressbar= (True) if True, display a tqdm progress bar when integrating multiple orbits (requires tqdm to be installed!)
        dt= (None) force integrator to use this stepsize (default is to automatically determine one; only for C-based integrators)
     OUTPUT:
        (y,err)
@@ -476,6 +585,7 @@ def integrateFullOrbit(pot,yo,t,int_method,rtol=None,atol=None,numcores=1,
     HISTORY:
        2010-08-01 - Written - Bovy (NYU)
        2019-04-09 - Adapted to allow multiple objects and parallel mapping - Bovy (UofT)
+       2022-04-12 - Add progressbar - Bovy (UofT)
     """
     nophi= False
     if not int_method.lower() == 'dop853' and not int_method == 'odeint':
@@ -560,7 +670,8 @@ def integrateFullOrbit(pot,yo,t,int_method,rtol=None,atol=None,numcores=1,
     if len(yo) == 1: # Can't map a single value...
         out= numpy.atleast_3d(integrate_for_map(yo[0]).T).T
     else:
-        out= numpy.array((parallel_map(integrate_for_map,yo,numcores=numcores)))
+        out= numpy.array(parallel_map(integrate_for_map,yo,numcores=numcores,
+                                       progressbar=progressbar))
     if nophi:
         out= out[:,:,:5]
     return out, numpy.zeros(len(yo))
@@ -570,7 +681,7 @@ def _RZEOM(y,t,pot,l2):
     NAME:
        _RZEOM
     PURPOSE:
-       implements the EOM, i.e., the right-hand side of the differential 
+       implements the EOM, i.e., the right-hand side of the differential
        equation, for a 3D orbit assuming conservation of angular momentum
     INPUT:
        y - current phase-space position
@@ -592,7 +703,7 @@ def _EOM(y,t,pot):
     NAME:
        _EOM
     PURPOSE:
-       implements the EOM, i.e., the right-hand side of the differential 
+       implements the EOM, i.e., the right-hand side of the differential
        equation, for a 3D orbit
     INPUT:
        y - current phase-space position
@@ -608,7 +719,7 @@ def _EOM(y,t,pot):
             l2/y[0]**3.+_evaluateRforces(pot,y[0],y[4],phi=y[2],t=t,
                                          v=[y[1],y[0]*y[3],y[5]]),
             y[3],
-            1./y[0]**2.*(_evaluatephiforces(pot,y[0],y[4],phi=y[2],t=t,
+            1./y[0]**2.*(_evaluatephitorques(pot,y[0],y[4],phi=y[2],t=t,
                                             v=[y[1],y[0]*y[3],y[5]])
                          -2.*y[0]*y[1]*y[3]),
             y[5],
@@ -638,8 +749,7 @@ def _rectForce(x,pot,t=0.):
     if x[1] < 0.: phi= 2.*numpy.pi-phi
     #calculate forces
     Rforce= _evaluateRforces(pot,R,x[2],phi=phi,t=t)
-    phiforce= _evaluatephiforces(pot,R,x[2],phi=phi,t=t)
-    return numpy.array([cosphi*Rforce-1./R*sinphi*phiforce,
-                     sinphi*Rforce+1./R*cosphi*phiforce,
+    phitorque= _evaluatephitorques(pot,R,x[2],phi=phi,t=t)
+    return numpy.array([cosphi*Rforce-1./R*sinphi*phitorque,
+                     sinphi*Rforce+1./R*cosphi*phitorque,
                      _evaluatezforces(pot,R,x[2],phi=phi,t=t)])
-
