@@ -1,17 +1,18 @@
 ###############################################################################
-#   ChandrasekharDynamicalFrictionForce: Class that implements the 
+#   ChandrasekharDynamicalFrictionForce: Class that implements the
 #                                        Chandrasekhar dynamical friction
 ###############################################################################
 import copy
 import hashlib
+
 import numpy
-from scipy import special, interpolate
-from ..util import bovy_conversion
+from scipy import interpolate, special
+
+from ..util import conversion
 from .DissipativeForce import DissipativeForce
-from .Potential import _APY_LOADED, evaluateDensities, _check_c
+from .Potential import _check_c, evaluateDensities
 from .Potential import flatten as flatten_pot
-if _APY_LOADED:
-    from astropy import units
+
 _INVSQRTTWO= 1./numpy.sqrt(2.)
 _INVSQRTPI= 1./numpy.sqrt(numpy.pi)
 class ChandrasekharDynamicalFrictionForce(DissipativeForce):
@@ -85,12 +86,9 @@ class ChandrasekharDynamicalFrictionForce(DissipativeForce):
         """
         DissipativeForce.__init__(self,amp=amp*GMs,ro=ro,vo=vo,
                                   amp_units='mass')
-        if _APY_LOADED and isinstance(rhm,units.Quantity):
-            rhm= rhm.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(minr,units.Quantity):
-            minr= minr.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(maxr,units.Quantity):
-            maxr= maxr.to(units.kpc).value/self._ro
+        rhm= conversion.parse_length(rhm,ro=self._ro)
+        minr= conversion.parse_length(minr,ro=self._ro)
+        maxr= conversion.parse_length(maxr,ro=self._ro)
         self._gamma= gamma
         self._ms= self._amp/amp # from handling in __init__ above, should be ms in galpy units
         self._rhm= rhm
@@ -115,7 +113,7 @@ class ChandrasekharDynamicalFrictionForce(DissipativeForce):
             sigmar= lambda x: jeans.sigmar(self._dens_pot,x,beta=0.,
                                            use_physical=False)
         self._sigmar_rs_4interp= numpy.linspace(self._minr,self._maxr,nr)
-        self._sigmars_4interp= numpy.array([sigmar(x) 
+        self._sigmars_4interp= numpy.array([sigmar(x)
                                             for x in self._sigmar_rs_4interp])
         if numpy.any(numpy.isnan(self._sigmars_4interp)):
             # Check for case where density is zero, in that case, just
@@ -123,8 +121,8 @@ class ChandrasekharDynamicalFrictionForce(DissipativeForce):
             # (doesn't matter in the end, because force = 0 when dens = 0)
             nanrs_indx= numpy.isnan(self._sigmars_4interp)
             if numpy.all(numpy.array([self._dens(r*_INVSQRTTWO,r*_INVSQRTTWO)
-                                      for r in 
-                                      self._sigmar_rs_4interp[nanrs_indx]]) 
+                                      for r in
+                                      self._sigmar_rs_4interp[nanrs_indx]])
                          == 0.):
                 self._sigmars_4interp[nanrs_indx]= interpolate.interp1d(\
                     self._sigmar_rs_4interp[True^nanrs_indx],
@@ -144,19 +142,7 @@ class ChandrasekharDynamicalFrictionForce(DissipativeForce):
         return None
 
     def GMs(self,gms):
-        if _APY_LOADED and isinstance(gms,units.Quantity):
-            try:
-                gms= gms.to(units.Msun).value\
-                    /bovy_conversion.mass_in_msol(self._vo,self._ro)
-            except units.UnitConversionError:
-                # Try G x mass
-                try:
-                    gms= gms.to(units.pc*units.km**2/units.s**2)\
-                        .value\
-                        /bovy_conversion.mass_in_msol(self._vo,self._ro)\
-                        /bovy_conversion._G
-                except units.UnitConversionError:
-                    raise units.UnitConversionError('GMs for %s should have units of mass or G x mass' % (type(self).__name__))
+        gms= conversion.parse_mass(gms,ro=self._ro,vo=self._vo)
         self._amp*= gms/self._ms
         self._ms= gms
         # Reset the hash
@@ -165,14 +151,12 @@ class ChandrasekharDynamicalFrictionForce(DissipativeForce):
     GMs= property(None,GMs)
 
     def rhm(self,new_rhm):
-        if _APY_LOADED and isinstance(new_rhm,units.Quantity):
-            new_rhm= new_rhm.to(units.kpc).value/self._ro
-        self._rhm= new_rhm
+        self._rhm= conversion.parse_length(new_rhm,ro=self._ro)
         # Reset the hash
         self._force_hash= None
         return None
-    rhm= property(None,rhm)        
-    
+    rhm= property(None,rhm)
+
     def lnLambda(self,r,v):
         """
         NAME:
@@ -195,7 +179,7 @@ class ChandrasekharDynamicalFrictionForce(DissipativeForce):
                 Lambda= r/self._gamma/self._rhm
             else:
                 Lambda= r/self._gamma/GMvs
-            lnLambda= 0.5*numpy.log(1.+Lambda**2.) 
+            lnLambda= 0.5*numpy.log(1.+Lambda**2.)
         return lnLambda
 
     def _calc_force(self,R,phi,z,v,t):
@@ -238,12 +222,12 @@ class ChandrasekharDynamicalFrictionForce(DissipativeForce):
             self._calc_force(R,phi,z,v,t)
         return self._cached_force*v[0]
 
-    def _phiforce(self,R,z,phi=0.,t=0.,v=None):
+    def _phitorque(self,R,z,phi=0.,t=0.,v=None):
         """
         NAME:
-           _phiforce
+           _phitorque
         PURPOSE:
-           evaluate the azimuthal force for this potential
+           evaluate the azimuthal torque for this potential
         INPUT:
            R - Galactocentric cylindrical radius
            z - vertical height
@@ -251,7 +235,7 @@ class ChandrasekharDynamicalFrictionForce(DissipativeForce):
            t - time
            v= current velocity in cylindrical coordinates
         OUTPUT:
-           the azimuthal force
+           the azimuthal torque
         HISTORY:
            2018-03-18 - Started - Bovy (UofT)
         """
