@@ -2,9 +2,11 @@
 #   DissipativeForce.py: top-level class for non-conservative forces
 ###############################################################################
 import numpy
+
+from ..util.conversion import physical_conversion, potential_physical_input
 from .Force import Force
-from ..util.bovy_conversion import physical_conversion, \
-    potential_physical_input
+
+
 class DissipativeForce(Force):
     """Top-level class for non-conservative forces (cannot be derived from a potential function)"""
     def __init__(self,amp=1.,ro=None,vo=None,amp_units=None):
@@ -68,7 +70,7 @@ class DissipativeForce(Force):
             raise
             from .Potential import PotentialError
             raise PotentialError("'_Rforce' function not implemented for this DissipativeForce")
-        
+
     @potential_physical_input
     @physical_conversion('force',pop=True)
     def zforce(self,R,z,phi=0.,t=0.,v=None):
@@ -114,15 +116,15 @@ class DissipativeForce(Force):
 
     @potential_physical_input
     @physical_conversion('force',pop=True)
-    def phiforce(self,R,z,phi=0.,t=0.,v=None):
+    def phitorque(self,R,z,phi=0.,t=0.,v=None):
         """
         NAME:
 
-           phiforce
+           phitorque
 
         PURPOSE:
 
-           evaluate the azimuthal force F_phi  (R,z,phi,t,v)
+           evaluate the azimuthal torque F_phi  (R,z,phi,t,v)
 
         INPUT:
 
@@ -145,16 +147,16 @@ class DissipativeForce(Force):
            2018-03-16 - Written - Bovy (UofT)
 
         """
-        return self._phiforce_nodecorator(R,z,phi=phi,t=t,v=v)
+        return self._phitorque_nodecorator(R,z,phi=phi,t=t,v=v)
 
-    def _phiforce_nodecorator(self,R,z,phi=0.,t=0.,v=None):
+    def _phitorque_nodecorator(self,R,z,phi=0.,t=0.,v=None):
         # Separate, so it can be used during orbit integration
         try:
-            return self._amp*self._phiforce(R,z,phi=phi,t=t,v=v)
+            return self._amp*self._phitorque(R,z,phi=phi,t=t,v=v)
         except AttributeError: #pragma: no cover
             if self.isNonAxi:
                 from .Potential import PotentialError
-                raise PotentialError("'_phiforce' function not implemented for this DissipativeForce")
+                raise PotentialError("'_phitorque' function not implemented for this DissipativeForce")
             return 0.
 
 def _isDissipative(obj):
@@ -189,4 +191,3 @@ def _isDissipative(obj):
     else:
         nonCons= isinstance(obj,DissipativeForce)
     return nonCons
-
