@@ -7,17 +7,22 @@
 ###############################################################################
 import numpy
 from scipy import special
-from .Potential import Potential, kms_to_kpcGyrDecorator, \
-    _APY_LOADED
-if _APY_LOADED:
-    from astropy import units
+
+from ..util import conversion
+from ..util._optional_deps import _JAX_LOADED
+from .Potential import Potential, kms_to_kpcGyrDecorator
+
+if _JAX_LOADED:
+   import jax.numpy as jnp
+   import jax.scipy.special as jspecial
+
 class PowerSphericalPotentialwCutoff(Potential):
-    """Class that implements spherical potentials that are derived from 
+    """Class that implements spherical potentials that are derived from
     power-law density models
 
     .. math::
 
-        \\rho(r) = \\mathrm{amp}\,\\left(\\frac{r_1}{r}\\right)^\\alpha\\,\\exp\\left(-(r/rc)^2\\right)
+        \\rho(r) = \\mathrm{amp}\\,\\left(\\frac{r_1}{r}\\right)^\\alpha\\,\\exp\\left(-(r/rc)^2\\right)
 
     """
     def __init__(self,amp=1.,alpha=1.,rc=1.,normalize=False,r1=1.,
@@ -55,10 +60,8 @@ class PowerSphericalPotentialwCutoff(Potential):
 
         """
         Potential.__init__(self,amp=amp,ro=ro,vo=vo,amp_units='density')
-        if _APY_LOADED and isinstance(r1,units.Quantity):
-            r1= r1.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(rc,units.Quantity):
-            rc= rc.to(units.kpc).value/self._ro
+        r1= conversion.parse_length(r1,ro=self._ro)
+        rc= conversion.parse_length(rc,ro=self._ro)
         self.alpha= alpha
         # Back to old definition
         self._amp*= r1**self.alpha
@@ -90,7 +93,15 @@ class PowerSphericalPotentialwCutoff(Potential):
            2013-06-28 - Started - Bovy (IAS)
         """
         r= numpy.sqrt(R**2.+z**2.)
-        return 2.*numpy.pi*self.rc**(3.-self.alpha)/r*(r/self.rc*special.gamma(1.-self.alpha/2.)*special.gammainc(1.-self.alpha/2.,(r/self.rc)**2.)-special.gamma(1.5-self.alpha/2.)*special.gammainc(1.5-self.alpha/2.,(r/self.rc)**2.))
+        out= 2.*numpy.pi*self.rc**(3.-self.alpha)*(1/self.rc*special.gamma(1.-self.alpha/2.)*special.gammainc(1.-self.alpha/2.,(r/self.rc)**2.)-special.gamma(1.5-self.alpha/2.)*special.gammainc(1.5-self.alpha/2.,(r/self.rc)**2.)/r)
+        if isinstance(r,(float,int)):
+            if r == 0:
+                return 0.
+            else:
+                return out
+        else:
+            out[r==0]= 0.
+            return out
 
     def _Rforce(self,R,z,phi=0.,t=0.):
         """
@@ -190,6 +201,79 @@ class PowerSphericalPotentialwCutoff(Potential):
         return R*z*(4.*numpy.pi*r**(-2.-self.alpha)*numpy.exp(-(r/self.rc)**2.)
                     -3.*self._mass(r)/r**5.)
 
+    def _rforce_jax(self,r):
+        """
+        NAME:
+           _rforce_jax
+        PURPOSE:
+           evaluate the spherical radial force for this potential using JAX; use incomplete gamma implementation rather than hypergeometric, because JAX doesn't have the hypergeometric functions currently
+        INPUT:
+           r - Galactocentric spherical radius
+        OUTPUT:
+           the radial force
+        HISTORY:
+           2022-05-10 - Written - Bovy (UofT)
+        """
+        if not _JAX_LOADED: # pragma: no cover
+            raise ImportError("Making use of the _rforce_jax function requires the google/jax library")
+        return -self._amp*2.*numpy.pi*self.rc**(3.-self.alpha)\
+            *jspecial.gammainc(1.5-0.5*self.alpha,(r/self.rc)**2.)\
+            *numpy.exp(jspecial.gammaln(1.5-0.5*self.alpha))/r**2
+
+    def _ddensdr(self,r,t=0.):
+        """
+        NAME:
+           _ddensdr
+        PURPOSE:
+            evaluate the radial density derivative for this potential
+        INPUT:
+           r - spherical radius
+           t= time
+        OUTPUT:
+           the density derivative
+        HISTORY:
+           2021-12-15 - Written - Lane (UofT)
+        """
+        return -self._amp*r**(-1.-self.alpha)*numpy.exp(-(r/self.rc)**2.)\
+            *(2.*r**2./self.rc**2.+self.alpha)
+
+    def _d2densdr2(self,r,t=0.):
+        """
+        NAME:
+           _d2densdr2
+        PURPOSE:
+           evaluate the second radial density derivative for this potential
+        INPUT:
+           r - spherical radius
+           t= time
+        OUTPUT:
+           the 2nd density derivative
+        HISTORY:
+           2021-12-15 - Written - Lane (UofT)
+        """
+        return self._amp*r**(-2.-self.alpha)*numpy.exp(-(r/self.rc)**2)\
+            *(self.alpha**2.+self.alpha+4*self.alpha*r**2./self.rc**2.\
+            -2.*r**2./self.rc**2.+4.*r**4./self.rc**4.)
+
+    def _ddenstwobetadr(self,r,beta=0):
+        """
+        NAME:
+           _ddenstwobetadr
+        PURPOSE:
+           evaluate the radial density derivative x r^(2beta) for this potential
+        INPUT:
+           r - spherical radius
+           beta= (0)
+        OUTPUT:
+           d (rho x r^{2beta} ) / d r
+        HISTORY:
+           2021-03-15 - Written - Lane (UofT)
+        """
+        if not _JAX_LOADED: # pragma: no cover
+            raise ImportError("Making use of _rforce_jax function requires the google/jax library")
+        return -self._amp*jnp.exp(-(r/self.rc)**2.)/r**(self.alpha-2.*beta)\
+                         *((self.alpha-2.*beta)/r+2.*r/self.rc**2.)
+
     def _dens(self,R,z,phi=0.,t=0.):
         """
         NAME:
@@ -209,7 +293,7 @@ class PowerSphericalPotentialwCutoff(Potential):
         r= numpy.sqrt(R**2.+z**2.)
         return 1./r**self.alpha*numpy.exp(-(r/self.rc)**2.)
 
-    def _mass(self,R,z=0.,t=0.):
+    def _mass(self,R,z=None,t=0.):
         """
         NAME:
            _mass
@@ -223,10 +307,12 @@ class PowerSphericalPotentialwCutoff(Potential):
            the mass enclosed
         HISTORY:
            2013-XX-XX - Written - Bovy (IAS)
+           2021-04-07 - Switched to hypergeometric function equivalent to incomplete gamma function for better behavior at alpha < -3 - Bovy (UofT)
         """
-        if z is None: r= R
-        else: r= numpy.sqrt(R**2.+z**2.)
-        return 2.*numpy.pi*self.rc**(3.-self.alpha)*special.gammainc(1.5-self.alpha/2.,(r/self.rc)**2.)*special.gamma(1.5-self.alpha/2.)
+        if z is not None: raise AttributeError # use general implementation
+        return 2.*numpy.pi*R**(3.-self.alpha)/(1.5-self.alpha/2.)\
+            *special.hyp1f1(1.5-self.alpha/2.,2.5-self.alpha/2.,
+                            -(R/self.rc)**2.)
 
     @kms_to_kpcGyrDecorator
     def _nemo_accpars(self,vo,ro):
@@ -255,4 +341,4 @@ class PowerSphericalPotentialwCutoff(Potential):
 
         """
         ampl= self._amp*vo**2.*ro**(self.alpha-2.)
-        return "0,%s,%s,%s" % (ampl,self.alpha,self.rc*ro)
+        return f"0,{ampl},{self.alpha},{self.rc*ro}"
