@@ -3,15 +3,17 @@
 ###############################################################################
 import numpy
 from scipy import special
-from .Potential import Potential, _APY_LOADED
-if _APY_LOADED:
-    from astropy import units
+
+from ..util import conversion
+from .Potential import Potential
+
+
 class RingPotential(Potential):
     """Class that implements the potential of an infinitesimally-thin, circular ring
 
     .. math::
 
-        \\rho(R,z) = \\frac{\\mathrm{amp}}{2\pi\,R_0}\\,\\delta(R-R_0)\\,\\delta(z)
+        \\rho(R,z) = \\frac{\\mathrm{amp}}{2\\pi\\,R_0}\\,\\delta(R-R_0)\\,\\delta(z)
 
     with :math:`\\mathrm{amp} = GM` the mass of the ring.
     """
@@ -45,8 +47,7 @@ class RingPotential(Potential):
 
         """
         Potential.__init__(self,amp=amp,ro=ro,vo=vo,amp_units='mass')
-        if _APY_LOADED and isinstance(a,units.Quantity):
-            a= a.to(units.kpc).value/self._ro
+        a= conversion.parse_length(a,ro=self._ro)
         self.a= a
         self.a2= self.a**2
         self._amp/= 2.*numpy.pi*self.a
@@ -75,7 +76,8 @@ class RingPotential(Potential):
         HISTORY:
            2018-08-04 - Written - Bovy (UofT)
         """
-        m= 4.*R*self.a/((R+self.a)**2+z**2)
+        # Stable as r -> infty
+        m= 4.*self.a/((numpy.sqrt(R)+self.a/numpy.sqrt(R))**2+z**2/R)
         return -4.*self.a/numpy.sqrt((R+self.a)**2+z**2)*special.ellipk(m)
 
     def _Rforce(self,R,z,phi=0.,t=0.):
@@ -145,7 +147,7 @@ class RingPotential(Potential):
                 +0.5*R2ma2mz2o4aR1m*(special.ellipe(m)-special.ellipk(m))
                 +0.5*(special.ellipe(m)/(1.-m)-special.ellipk(m))/m)\
                                   *4*self.a*(self.a2+z**2-R**2)/Raz2**2)
-    
+
     def _z2deriv(self,R,z,phi=0.,t=0.):
         """
         NAME:
@@ -164,13 +166,13 @@ class RingPotential(Potential):
         """
         Raz2= (R+self.a)**2+z**2
         m= 4.*R*self.a/Raz2
-        # Explicitly swapped in zforce here, so the z/z can be cancelled 
+        # Explicitly swapped in zforce here, so the z/z can be cancelled
         # and z=0 is handled properly
         return -4.*(3.*z**2/Raz2-1.
                     +4.*((1.+m)/(1.-m)-special.ellipk(m)/special.ellipe(m))\
                         *self.a*R*z**2/Raz2**2/m)\
                     *self.a/(1.-m)*((R+self.a)**2+z**2)**-1.5*special.ellipe(m)
-     
+
     def _Rzderiv(self,R,z,phi=0.,t=0.):
         """
         NAME:
