@@ -6,23 +6,23 @@
 #
 #  Phi(r, phi, z) = -4*pi*G*H*rho0*exp(-(r-r0)/Rs)*sum(Cn/(Kn*Dn)*cos(n*gamma)*sech(Kn*z/Bn)^Bn)
 ###############################################################################
-from __future__ import division
-from .Potential import Potential, _APY_LOADED
-from ..util import bovy_conversion
 import numpy
-if _APY_LOADED:
-    from astropy import units
+
+from ..util import conversion
+from .Potential import Potential
+
+
 class SpiralArmsPotential(Potential):
-    """Class that implements the spiral arms potential from (`Cox and Gomez 2002 <https://arxiv.org/abs/astro-ph/0207635>`__). Should be used to modulate an existing potential (density is positive in the arms, negative outside).
-    
+    """Class that implements the spiral arms potential from (`Cox and Gomez 2002 <https://arxiv.org/abs/astro-ph/0207635>`__). Should be used to modulate an existing potential (density is positive in the arms, negative outside; note that because of this, a contour plot of this potential will appear to have twice as many arms, where half are the underdense regions).
+
     .. math::
-    
-        \\Phi(R, \\phi, z) = -4 \\pi GH \\,\\rho_0 exp \\left( -\\frac{R-r_{ref}}{R_s} \\right) \\sum{\\frac{C_n}{K_n D_n} \\,\cos(n \\gamma) \\,\\mathrm{sech}^{B_n} \\left( \\frac{K_n z}{B_n} \\right)}
+
+        \\Phi(R, \\phi, z) = -4 \\pi GH \\,\\rho_0 exp \\left( -\\frac{R-r_{ref}}{R_s} \\right) \\sum{\\frac{C_n}{K_n D_n} \\,\\cos(n \\gamma) \\,\\mathrm{sech}^{B_n} \\left( \\frac{K_n z}{B_n} \\right)}
 
     where
 
     .. math::
-        K_n &= \\frac{n N}{R \sin(\\alpha)} \\\\
+        K_n &= \\frac{n N}{R \\sin(\\alpha)} \\\\
         B_n &= K_n H (1 + 0.4 K_n H) \\\\
         D_n &= \\frac{1 + K_n H + 0.3 (K_n H)^2}{1 + 0.3 K_n H} \\\\
 
@@ -31,10 +31,10 @@ class SpiralArmsPotential(Potential):
     .. math::
         \\gamma = N \\left[\\phi - \\phi_{ref} - \\frac{\\ln(R/r_{ref})}{\\tan(\\alpha)} \\right]
 
-    The default of :math:`C_n=[1]` gives a sinusoidal profile for the potential. An alternative from `Cox and Gomez (2002) <https://arxiv.org/abs/astro-ph/0207635>`__  creates a density that behaves approximately as a cosine squared in the arms but is separated by a flat interarm region by setting 
+    The default of :math:`C_n=[1]` gives a sinusoidal profile for the potential. An alternative from `Cox and Gomez (2002) <https://arxiv.org/abs/astro-ph/0207635>`__  creates a density that behaves approximately as a cosine squared in the arms but is separated by a flat interarm region by setting
 
      .. math::
-        C_n = \\left[\\frac{8}{3 \\pi}\,,\\frac{1}{2} \\,, \\frac{8}{15 \\pi}\\right]
+        C_n = \\left[\\frac{8}{3 \\pi}\\,,\\frac{1}{2} \\,, \\frac{8}{15 \\pi}\\right]
 
     """
     normalize= property() # turn off normalize
@@ -42,12 +42,12 @@ class SpiralArmsPotential(Potential):
                  N=2, alpha=0.2, r_ref=1, phi_ref=0, Rs=0.3, H=0.125, omega=0, Cs=[1]):
 
         """
-        NAME:       
+        NAME:
             __init__
         PURPOSE:
             initialize a spiral arms potential
         INPUT:
-            :amp: amplitude to be applied to the potential (default: 1); 
+            :amp: amplitude to be applied to the potential (default: 1);
                         can be a Quantity with units of density. (:math:`amp = 4 \\pi G \\rho_0`)
             :ro: distance scales for translation into internal units (default from configuration file)
             :vo: velocity scales for translation into internal units (default from configuration file)
@@ -57,7 +57,7 @@ class SpiralArmsPotential(Potential):
             :phi_ref: reference angle (:math:`\\phi_p(r_0)` in the paper by Cox and Gomez) (can be Quantity)
             :Rs: radial scale length of the drop-off in density amplitude of the arms (can be Quantity)
             :H: scale height of the stellar arm perturbation (can be Quantity)
-            :Cs: list of constants multiplying the :math:`\cos(n \\gamma)` terms
+            :Cs: list of constants multiplying the :math:`\\cos(n \\gamma)` terms
             :omega: rotational pattern speed of the spiral arms (can be Quantity)
         OUTPUT:
             (none)
@@ -68,21 +68,12 @@ class SpiralArmsPotential(Potential):
         """
 
         Potential.__init__(self, amp=amp, ro=ro, vo=vo, amp_units=amp_units)
-        if _APY_LOADED:
-            if isinstance(alpha, units.Quantity):
-                alpha = alpha.to(units.rad).value
-            if isinstance(r_ref, units.Quantity):
-                r_ref = r_ref.to(units.kpc).value / self._ro
-            if isinstance(phi_ref, units.Quantity):
-                phi_ref = phi_ref.to(units.rad).value
-            if isinstance(Rs, units.Quantity):
-                Rs = Rs.to(units.kpc).value / self._ro
-            if isinstance(H, units.Quantity):
-                H = H.to(units.kpc).value / self._ro
-            if isinstance(omega, units.Quantity):
-                omega = omega.to(units.km / units.s / units.kpc).value \
-                        / bovy_conversion.freq_in_kmskpc(self._vo, self._ro)
-
+        alpha= conversion.parse_angle(alpha)
+        r_ref= conversion.parse_length(r_ref,ro=self._ro)
+        phi_ref= conversion.parse_angle(phi_ref)
+        Rs= conversion.parse_length(Rs,ro=self._ro)
+        H= conversion.parse_length(H,ro=self._ro)
+        omega= conversion.parse_frequency(omega,ro=self._ro,vo=self._vo)
         self._N = -N  # trick to flip to left handed coordinate system; flips sign for phi and phi_ref, but also alpha.
         self._alpha = -alpha  # we don't want sign for alpha to change, so flip alpha. (see eqn. 3 in the paper)
         self._sin_alpha = numpy.sin(-alpha)
@@ -101,7 +92,7 @@ class SpiralArmsPotential(Potential):
         self.hasC = True       # Potential has C implementation to speed up orbit integrations
         self.hasC_dxdv = True  # Potential has C implementation of second derivatives
 
-    
+
     def _evaluate(self, R, z, phi=0, t=0):
         """
         NAME:
@@ -135,7 +126,7 @@ class SpiralArmsPotential(Potential):
         return -self._H * numpy.exp(-(R-self._r_ref) / self._Rs) \
                * numpy.sum(self._Cs / Ks / Ds * numpy.cos(self._ns * self._gamma(R, phi - self._omega * t)) / numpy.cosh(Ks * z / Bs) ** Bs,axis=0)
 
-    
+
     def _Rforce(self, R, z, phi=0, t=0):
         """
         NAME:
@@ -188,7 +179,7 @@ class SpiralArmsPotential(Potential):
                                                                         + dDs_dR / Ds / Ks))
                                                            + cos_ng / Ks / self._Rs),axis=0)
 
-    
+
     def _zforce(self, R, z, phi=0, t=0):
         """
         NAME:
@@ -203,7 +194,7 @@ class SpiralArmsPotential(Potential):
         OUTPUT:
             :return: the vertical force
         HISTORY:
-            2017-05-25  Jack Hong (UBC) 
+            2017-05-25  Jack Hong (UBC)
         """
         if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
             nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
@@ -224,20 +215,19 @@ class SpiralArmsPotential(Potential):
                * numpy.sum(self._Cs / Ds * numpy.cos(self._ns * self._gamma(R, phi - self._omega * t))
                         * numpy.tanh(zK_B) / numpy.cosh(zK_B)**Bs,axis=0)
 
-    
-    def _phiforce(self, R, z, phi=0, t=0):
+    def _phitorque(self, R, z, phi=0, t=0):
         """
         NAME:
-            _phiforce
+            _phitorque
         PURPOSE:
-            Evaluate the azimuthal force in cylindrical coordinates. (-dPhi/dphi)
+            Evaluate the azimuthal torque in cylindrical coordinates. (-dPhi/dphi)
         INPUT:
             :param R: galactocentric cylindrical radius
             :param z: vertical height
             :param phi: azimuth
             :param t: time
         OUTPUT:
-            :return: the azimuthal force
+            :return: the azimuthal torque
         HISTORY:
             2017-05-25  Jack Hong (UBC)
         """
@@ -259,7 +249,7 @@ class SpiralArmsPotential(Potential):
         return -self._H * numpy.exp(-(R-self._r_ref) / self._Rs) \
                * numpy.sum(self._N * self._ns * self._Cs / Ds / Ks / numpy.cosh(z * Ks / Bs)**Bs * numpy.sin(self._ns * g),axis=0)
 
-    
+
     def _R2deriv(self, R, z, phi=0, t=0):
         """
         NAME:
@@ -358,7 +348,7 @@ class SpiralArmsPotential(Potential):
                                                                      + log_sechzKB * dBs_dR))
                                                        + sin_ng * self._ns * dg_dR)))),axis=0))
 
-    
+
     def _z2deriv(self, R, z, phi=0, t=0):
         """
         NAME:
@@ -374,7 +364,7 @@ class SpiralArmsPotential(Potential):
         OUTPUT:
             :return: the second vertical derivative
         HISTORY:
-            2017-05-26  Jack Hong (UBC) 
+            2017-05-26  Jack Hong (UBC)
         """
         if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
             nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
@@ -396,7 +386,7 @@ class SpiralArmsPotential(Potential):
         return -self._H * numpy.exp(-(R-self._r_ref)/self._Rs) \
                * numpy.sum(self._Cs * Ks / Ds * ((tanh2_zKB - 1) / Bs + tanh2_zKB) * numpy.cos(self._ns * g) / numpy.cosh(zKB)**Bs,axis=0)
 
-    
+
     def _phi2deriv(self, R, z, phi=0, t=0):
         """
         NAME:
@@ -432,7 +422,7 @@ class SpiralArmsPotential(Potential):
         return self._H * numpy.exp(-(R-self._r_ref) / self._Rs) \
                * numpy.sum(self._Cs * self._N**2. * self._ns**2. / Ds / Ks / numpy.cosh(z*Ks/Bs)**Bs * numpy.cos(self._ns*g),axis=0)
 
-    
+
     def _Rzderiv(self, R, z, phi=0., t=0.):
         """
         NAME:
@@ -493,7 +483,7 @@ class SpiralArmsPotential(Potential):
                                                                         + dBs_dR / Bs * tanhzKB)
                                                                        - tanhzKB / Rs)),axis=0)
 
-    
+
     def _Rphideriv(self, R, z, phi=0,t=0):
         """
         NAME:
@@ -548,7 +538,42 @@ class SpiralArmsPotential(Potential):
                                                     + dDs_dR / Ds
                                                     + 1 / self._Rs))),axis=0)
 
-    
+
+    def _phizderiv(self, R, z, phi=0, t=0):
+        """
+        NAME:
+            _phizderiv
+        PURPOSE:
+            Evaluate the mixed azimuthal, vertical derivative for this potential at the given coordinates. (-dPhi/dz)
+        INPUT:
+            :param R: galactocentric cylindrical radius
+            :param z: vertical height
+            :param phi: azimuth
+            :param t: time
+        OUTPUT:
+            :return: mixed azimuthal, vertical derivative
+        HISTORY:
+            2021-04-30 - Jo Bovy (UofT)
+        """
+        if isinstance(R,numpy.ndarray) or isinstance(z,numpy.ndarray):
+            nR= len(R) if isinstance(R,numpy.ndarray) else len(z)
+            self._Cs=numpy.transpose(numpy.array([self._Cs0,]*nR))
+            self._ns=numpy.transpose(numpy.array([self._ns0,]*nR))
+            self._HNn=numpy.transpose(numpy.array([self._HNn0,]*nR))
+        else:
+            self._Cs=self._Cs0
+            self._ns=self._ns0
+            self._HNn=self._HNn0
+
+        Ks = self._K(R)
+        Bs = self._B(R)
+        Ds = self._D(R)
+        zK_B = z * Ks / Bs
+
+        return -self._H * numpy.exp(-(R-self._r_ref) / self._Rs) \
+               * numpy.sum(self._Cs / Ds * self._ns * self._N * numpy.sin(self._ns * self._gamma(R, phi - self._omega * t))
+                        * numpy.tanh(zK_B) / numpy.cosh(zK_B)**Bs,axis=0)
+
     def _dens(self, R, z, phi=0, t=0):
         """
         NAME:
