@@ -1,5 +1,5 @@
 ###############################################################################
-#   TwoPowerTriaxialPotential.py: General class for triaxial potentials 
+#   TwoPowerTriaxialPotential.py: General class for triaxial potentials
 #                                 derived from densities with two power-laws
 #
 #                                                    amp/[4pia^3]
@@ -12,10 +12,13 @@
 ###############################################################################
 import numpy
 from scipy import special
+
 from ..util import conversion
 from .EllipsoidalPotential import EllipsoidalPotential
+
+
 class TwoPowerTriaxialPotential(EllipsoidalPotential):
-    """Class that implements triaxial potentials that are derived from 
+    """Class that implements triaxial potentials that are derived from
     two-power density models
 
     .. math::
@@ -256,7 +259,7 @@ class TriaxialHernquistPotential(EllipsoidalPotential):
         """
         if not z is None: raise AttributeError # Hack to fall back to general
         return 4.*numpy.pi*self.a4/self.a/(1.+self.a/R)**2./2.*self._b*self._c
-    
+
 class TriaxialJaffePotential(EllipsoidalPotential):
     """Class that implements the Jaffe potential
 
@@ -344,7 +347,7 @@ class TriaxialJaffePotential(EllipsoidalPotential):
     def _mdens_deriv(self,m):
         """Derivative of the density as a function of m"""
         return -2.*self.a2**2*(self.a+2.*m)/m**3/(self.a+m)**3
-  
+
     def _mass(self,R,z=None,t=0.):
         """
         NAME:
@@ -362,7 +365,7 @@ class TriaxialJaffePotential(EllipsoidalPotential):
         """
         if not z is None: raise AttributeError # Hack to fall back to general
         return 4.*numpy.pi*self.a*self.a2/(1.+self.a/R)*self._b*self._c
-    
+
 class TriaxialNFWPotential(EllipsoidalPotential):
     """Class that implements the triaxial NFW potential
 
@@ -412,22 +415,22 @@ class TriaxialNFWPotential(EllipsoidalPotential):
            normalize - if True, normalize such that vc(1.,0.)=1., or, if given as a number, such that the force is this fraction of the force necessary to make vc(1.,0.)=1.
 
 
-           Alternatively, NFW potentials can be initialized using 
+           Alternatively, NFW potentials can be initialized using
 
               conc= concentration
 
               mvir= virial mass in 10^12 Msolar
 
            in which case you also need to supply the following keywords
-           
+
               H= (default: 70) Hubble constant in km/s/Mpc
-           
+
               Om= (default: 0.3) Omega matter
-       
+
               overdens= (200) overdensity which defines the virial radius
 
               wrtcrit= (False) if True, the overdensity is wrt the critical density rather than the mean matter density
-           
+
            ro=, vo= distance and velocity scales for translation into internal units (default from configuration file)
 
         OUTPUT:
@@ -449,10 +452,10 @@ class TriaxialNFWPotential(EllipsoidalPotential):
             self.a= a
         else:
             from ..potential import NFWPotential
-            dum= NFWPotential(mvir=mvir,conc=conc,ro=self._ro,vo=self._vo,
+            dumb= NFWPotential(mvir=mvir,conc=conc,ro=self._ro,vo=self._vo,
                               H=H,Om=Om,wrtcrit=wrtcrit,overdens=overdens)
-            self.a= dum.a
-            self._amp= dum._amp
+            self.a= dumb.a
+            self._amp= dumb._amp
         self._scale= self.a
         self.hasC= not self._glorder is None
         self.hasC_dxdv= False
@@ -496,4 +499,3 @@ class TriaxialNFWPotential(EllipsoidalPotential):
         if not z is None: raise AttributeError # Hack to fall back to general
         return 4.*numpy.pi*self.a3*self._b*self._c\
             *(numpy.log(1+R/self.a)-R/self.a/(1.+R/self.a))
-    
