@@ -1,16 +1,15 @@
-# galpy.potential.mwpotentials: Milky-Way-like potentials and tools for 
+# galpy.potential.mwpotentials: Milky-Way-like potentials and tools for
 # working with MW-like potentials (bars, spirals, ...)
-import sys
-import os
 import copy
-from . import HernquistPotential
-from . import MiyamotoNagaiPotential
-from . import NFWPotential
-from . import PowerSphericalPotentialwCutoff
+import os
+import sys
+
+from . import (HernquistPotential, MiyamotoNagaiPotential, NFWPotential,
+               PowerSphericalPotentialwCutoff)
 
 ############################ MILKY WAY MODELS #################################
-# galpy's first version of a MW-like potential, kept for backwards 
-# compatibility and reproducibility-of-results-in-the-literature reasons, 
+# galpy's first version of a MW-like potential, kept for backwards
+# compatibility and reproducibility-of-results-in-the-literature reasons,
 # underscore it here to avoid use
 _MWPotential= [MiyamotoNagaiPotential(a=0.5,b=0.0375,normalize=.6),
                NFWPotential(a=4.5,normalize=.35),
@@ -20,8 +19,8 @@ MWPotential2014= [PowerSphericalPotentialwCutoff(normalize=0.05,alpha=1.8,
                                                  rc=1.9/8.),
                   MiyamotoNagaiPotential(a=3./8.,b=0.28/8.,normalize=0.6),
                   NFWPotential(a=2.,normalize=0.35)]
-# Following class allows potentials that are expensive to setup to be 
-# lazily-loaded 
+# Following class allows potentials that are expensive to setup to be
+# lazily-loaded
 # (see https://stackoverflow.com/questions/1462986/lazy-module-variables-can-it-be-done)
 def _setup_globals(): # this func necessary to transfer *all* globals in Py2
     out= copy.copy(globals())
@@ -57,7 +56,7 @@ class _ExpensivePotentials:
             from galpy.potential.McMillan17 import McMillan17 as _McMillan17
             self._mcmillan17= _McMillan17
         return self._mcmillan17
-    
+
     @property
     def Cautun20(self):
         if not self._cautun20:
@@ -135,11 +134,9 @@ class _ExpensivePotentials:
             #In Py3 you can just do 'return globals()[name]', but not in Py2
             return self.__globals__[name]
         except: # pragma: no cover
-            raise AttributeError("'module' object has no attribute '{}'".format(name))
+            raise AttributeError(f"'module' object has no attribute '{name}'")
 
 __all__= ['MWPotential2014']
 
 # The magic to make lazy-loading of expensive potentials possible
 sys.modules[__name__] = _ExpensivePotentials()
-
-    
