@@ -1,14 +1,15 @@
 # Central place to process optional dependencies
-from pkg_resources import parse_version
+from packaging.version import parse as parse_version
 
 # astropy
 from ..util.config import __config__
+
 _APY_UNITS= __config__.getboolean('astropy','astropy-units')
 _APY_LOADED= True
 _APY3= None
 _APY_GE_31= None
 try:
-    from astropy import units, constants
+    from astropy import constants, units
 except ImportError:
     _APY_UNITS= False
     _APY_LOADED= False
@@ -22,14 +23,14 @@ try:
 except ImportError:
     SkyCoord = None
     _APY_COORD_LOADED= False
-    
+
 # astroquery
 _ASTROQUERY_LOADED= True
 try:
     from astroquery.simbad import Simbad
 except ImportError:
     _ASTROQUERY_LOADED= False
-    
+
 # numexpr
 _NUMEXPR_LOADED= True
 try:
@@ -43,11 +44,11 @@ try:
     import tqdm
 except ImportError: #pragma: no cover
     _TQDM_LOADED= False
-    
-# numba    
+
+# numba
 _NUMBA_LOADED= True
 try:
-    from numba import types, cfunc
+    from numba import cfunc, types
 except ImportError:
     _NUMBA_LOADED= False
 
@@ -57,10 +58,10 @@ try:
     from jax import grad, vmap
 except ImportError:
     _JAX_LOADED= False
-    
+
 # pynbody
 _PYNBODY_LOADED= True
-try: 
+try:
     import pynbody
 except ImportError: #pragma: no cover
     _PYNBODY_LOADED= False
